pacman::p_load(performance, vegan, lme4, effects, mgcv, glmmTMB, tidyr, dplyr, 
               sjPlot, FD, reshape2, betapart, RVAideMemoire, AICcmodavg, MuMIn,
               plyr, ggplot2, betapart, data.table, gamm4, forcats  , viridis, 
               gtools, ggeffects, ggtext, stringr, buildmer, ggpubr, maps, 
               mapdata, ggsn,ggrepel,emmeans, officer, flextable, SPEI)

#####Set working directory
setwd()

#####Data collation############
data<-read.csv(file="JP_beetledata.csv", na="0",check.names = F)

data[is.na(data)] <- 0
data$UID<-paste0("UID#", 1:nrow(data)) #give a unique ID
row.names(data)<-data$UID

plot_level_variables<-read.csv(file="JP_plot_level_vars.csv") #these are variables associated with each plot, regardless of when sampled
data<-left_join(data,plot_level_variables,by="MAIN_PLOT_ID") #

subplot_level_variables<-read.csv(file="JP_sampling vars.csv") #these are variables recorded each time a sample is taken (pitfall)
subplot_level_variables$PLOT_ID_sample_year<-paste(subplot_level_variables$PLOT_ID,subplot_level_variables$Year,subplot_level_variables$sampling,sep="_")
subplot_level_variables<-subplot_level_variables[,c("traps","disturb","days","PLOT_ID_sample_year")]

data$PLOT_ID_sample_year<-paste(data$PLOT_ID,data$Year,data$sampling,sep="_")

data<-left_join(data,subplot_level_variables)

data<-subset(data,traps==4)#remove irregularities
data<-subset(data,disturb==0)#remove disturbances
data<-subset(data, days<=5)#use as offset or covariate
data<-subset(data,!(MAIN_PLOT_ID %in% c("AS_DB2","TN_EB2","KM_DB2","CC_DB2","KS_DB1","KS_DB2"))) #removing some sites
data<-subset(data,Year>=2005)
data<-subset(data,ForestType!="AT") #Remove artificial plantations


justdata<-data[,-c(which(names(data)=="10-1-1-2"):which(names(data)=="9-99-99-99"))] #also removes the 99-99-99-99 beetle, they are grubs.

justbeetlesdata<-data[,c(which(names(data)=="10-1-1-2"):which(names(data)=="9-99-99-99"))] #check whether the columns are cor
justbeetlesdata <- justbeetlesdata[,(colSums(justbeetlesdata, na.rm=F) != 0)] # T if colSum is not 0, F otherwise

data<-cbind(justdata,justbeetlesdata)
row.names(justbeetlesdata)<-data$UID
data$yyyy<-substring(data$date,1,4)
data$month<-substring(data$date,5,6)
data$day<-substring(data$date,7,8)
data$beetle_biomass<-as.numeric(as.character(data$beetle_biomass))
data$ForestType<-factor(data$ForestType,levels=c("EB","BC","EC","DB","AT"))
data$FT<-revalue(data$ForestType, c("BC"="Broadleaf/\nconiferous\nmixed",
                                    "DB"="Deciduous\nbroadleaf","EC"="Evergreen\nconiferous", 
                                    "EB"="Evergreen\nbroadleaf"))

data$abundance<-rowSums(justbeetlesdata)
justbeetlesdata$`99-99-99-99`<-NULL
data$richness<-as.numeric(as.character(specnumber(justbeetlesdata)))
data$shannon<-diversity(justbeetlesdata)
data$evenness<-data$shannon/log(data$richness)

data$month_num<-as.numeric(data$month)
data$yyyy<-as.numeric(data$yyyy)
data$yyyy_scaled<-scale(data$yyyy)

data$date_proper<-as.Date(paste(data$day,"/",data$month,"/",data$yyyy,sep=""),"%d/%m/%Y")
data$date_cont<-scales::rescale(as.numeric(data$date_proper),to=c(min(data$yyyy,na.rm=T),max(data$yyyy,na.rm=T)))
data$beetle_biomass[which(data$abundance==0)]<-0


#####feeding groups#############
trait_data<-read.csv(file="JP_species_list.csv")
trait_data<-trait_data[which(trait_data$tax_no %in% names(justbeetlesdata)),]

trait_data<-trait_data[match(names(justbeetlesdata),trait_data$tax_no),]#order in same order as the justbeetlesdata

Feeding<-unique(trait_data$Feeding_guild)[complete.cases(unique(trait_data$Feeding_guild))]

sumtab<-data.frame(UID=row.names(justbeetlesdata))

for(i in 1:length(Feeding)) { 
  trait_temp<-subset(trait_data,Feeding_guild==Feeding[i])
  temp_colname<-paste(Feeding[i]," (abundance)",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_abund<-data.frame(rowSums(data.frame(temp_beetles)),"tempstuff")
  temp_abund<-temp_abund[ , 1, drop = FALSE]
  colnames(temp_abund)[1]<-temp_colname
  sumtab<-cbind(sumtab,temp_abund)
  
}

colSums(sumtab[,-1])

for(i in 1:length(Feeding)) { 
  trait_temp<-subset(trait_data,Feeding_guild==Feeding[i])
  temp_colname<-paste(Feeding[i]," (richness)",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_beetles<-ifelse(temp_beetles>=1,1,0)
  temp_rich<-data.frame(rowSums(data.frame(temp_beetles)),"tempstuff")
  temp_rich<-temp_rich[ , 1, drop = FALSE]
  colnames(temp_rich)[1]<-temp_colname
  sumtab<-cbind(sumtab,temp_rich)
  
}

colSums(sumtab[,-1])
data<-left_join(data,sumtab)

#biomass

mass_sumtab<-data[,"UID",drop=FALSE]

for(i in 1:length(Feeding)) { 
  trait_temp<-subset(trait_data,Feeding_guild==Feeding[i])
  temp_colname<-paste(Feeding[i]," (biomass)",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_mass_df<-data.frame(UID=data$UID, mass=rowSums(data.frame(sweep(temp_beetles, MARGIN=2, trait_data[match(colnames(temp_beetles),trait_data$tax_no),]$mass_mean, `*`)),na.rm = TRUE))
  colnames(temp_mass_df)[2]<-paste(Feeding[i]," (biomass)",sep="")
  mass_sumtab<-left_join(mass_sumtab,temp_mass_df)
  
}

data<-left_join(data,mass_sumtab)

chaos_sumtab<-data[,"UID",drop=FALSE]

for(i in 1:length(Feeding)) { 
  trait_temp<-subset(trait_data,Feeding_guild==Feeding[i])
  temp_colname<-paste(Feeding[i]," (Chao's S)",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_chaos<-estimateR(temp_beetles,datatype = "abundance")[2,]
  temp_chaos<-data.frame(round(temp_chaos, digits = 0))
  colnames(temp_chaos)[1]<-temp_colname
  chaos_sumtab<-cbind(chaos_sumtab,temp_chaos)
  
}

data<-left_join(data,chaos_sumtab)

######Community weighted means
#################FAMILY ################

families<-unique(trait_data$fam)

sumtab<-data.frame(UID=row.names(justbeetlesdata))

for(i in 1:length(families)) { 
  trait_temp<-subset(trait_data,fam==families[i])
  temp_colname<-paste(families[i],"_abundance",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_abund<-data.frame(rowSums(data.frame(temp_beetles)),"tempstuff")
  temp_abund<-temp_abund[ , 1, drop = FALSE]
  colnames(temp_abund)[1]<-temp_colname
  sumtab<-cbind(sumtab,temp_abund)
  
}

colSums(sumtab[,-1])

for(i in 1:length(families)) { 
  trait_temp<-subset(trait_data,fam==families[i])
  temp_colname<-paste(families[i],"_richness",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_beetles<-ifelse(temp_beetles>=1,1,0)
  temp_rich<-data.frame(rowSums(data.frame(temp_beetles)),"tempstuff")
  temp_rich<-temp_rich[ , 1, drop = FALSE]
  colnames(temp_rich)[1]<-temp_colname
  sumtab<-cbind(sumtab,temp_rich)
  
}

colSums(sumtab[,-1])

data<-left_join(data,sumtab)

#biomass
mass_sumtab<-data[,"UID",drop=FALSE]

for(i in 1:length(families)) { 
  trait_temp<-subset(trait_data,fam==families[i])
  temp_colname<-paste(families[i]," (biomass)",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no),drop=FALSE]
  temp_mass_df<-data.frame(UID=data$UID, mass=rowSums(data.frame(sweep(temp_beetles, MARGIN=2, trait_data[match(colnames(temp_beetles),trait_data$tax_no),]$mass_mean, `*`)),na.rm = TRUE))
  colnames(temp_mass_df)[2]<-paste(families[i]," (biomass)",sep="")
  mass_sumtab<-left_join(mass_sumtab,temp_mass_df)
  
}

data<-left_join(data,mass_sumtab)

chaos_families<-c("Carabidae","Geotrupidae","Staphylinidae","Silphidae")

chaos_sumtab<-data[,"UID",drop=FALSE]

for(i in 1:length(chaos_families)) { 
  trait_temp<-subset(trait_data,fam==chaos_families[i])
  temp_colname<-paste(chaos_families[i]," (Chao's S)",sep="")
  temp_beetles<-justbeetlesdata[,which(names(justbeetlesdata) %in% trait_temp$tax_no)]
  temp_chaos<-estimateR(temp_beetles,datatype = "abundance")[2,]
  temp_chaos<-data.frame(round(temp_chaos, digits = 0))
  colnames(temp_chaos)[1]<-temp_colname
  chaos_sumtab<-cbind(chaos_sumtab,temp_chaos)
  
}

data<-left_join(data,chaos_sumtab)

#####Determine seasons########
data$date_proper<-as.Date(paste(data$day,"/",data$month,"/",data$yyyy,sep=""),"%d/%m/%Y")
data$date_cont<-scales::rescale(as.numeric(data$date_proper),to=c(min(as.numeric(data$yyyy),na.rm=T),max(as.numeric(data$yyyy),na.rm=T)))

getSeason <- function(DATES) {
  WS <- as.Date("2012-12-15", format = "%Y-%m-%d") # Winter Solstice
  SE <- as.Date("2012-3-15",  format = "%Y-%m-%d") # Spring Equinox
  SS <- as.Date("2012-6-15",  format = "%Y-%m-%d") # Summer Solstice
  FE <- as.Date("2012-9-15",  format = "%Y-%m-%d") # Autumn Equinox
  
  # Convert dates from any year to 2012 dates
  d <- as.Date(strftime(DATES, format="2012-%m-%d"))
  
  ifelse (d >= WS | d < SE, "Winter",
          ifelse (d >= SE & d < SS, "Spring",
                  ifelse (d >= SS & d < FE, "Summer", "Autumn")))
}

data$season<-getSeason(data$date_proper)

###############CLIMATE##################

JPNCMI<-fread("JP_bioclim_export.csv")#Monthly data
JPNCMI<-JPNCMI[,.(PLOT_ID=Name, LAT=Latitude, LONG=Longitude, Year_Mon=JPNCMI$"Year-Month",
                  PPT=PptSum, PET=PetSum)]#, CMI=CMI)] #CMI should be re-calculated mannually cz BioSIM allocated 0 when PET>PPT
JPNCMI[,":="(CMI=PPT-PET)]
JPNCMI[,":="(Year=as.numeric(gsub("-.*","",Year_Mon)),
             Mon=as.numeric(gsub(".*-","",Year_Mon)))]
JPNCMI[,":="(MAP=sum(PPT),MPET=sum(PET)),by=.(Year,PLOT_ID)] #Mean Annual Precip

#Now calculate SPEI using the Annual CMI (based on the description in Searle 2020/EcolLett)
#Specify fit methods (fit="max-lik"), otherwise BC and QC will have Infinite values
JPNCMI[,SPEI:=spei(CMI,12,fit="max-lik")$fitted,by=PLOT_ID]
JPNCMI<-JPNCMI[Year>=2004,]#Delete the dummy 2003 data
JPNCMI[,ASPEI:=mean(SPEI),by=.(PLOT_ID,Year)]
JPNCMI[,ACMI:=sum(CMI),by=.(PLOT_ID,Year)]#Annual Climate Moisture Index
JPNCMI<-JPNCMI[Mon==12]
JPNCMI[,":="(Year_Mon=NULL,PPT=NULL,PET=NULL,CMI=NULL)]
JPNCMI<-unique(JPNCMI)

JPNCMI[,":="(MAPave=mean(MAP),
             CMIave=mean(ACMI)),by=PLOT_ID]#it was "Fifty_JPNCMI_Mean" but changed to "CMIave"
JPNCMI[,":="(APA=MAP-MAPave,#APA=anomaly of annual precipitation
             ACMIA=ACMI-CMIave)]
JPNCMI<-JPNCMI[order(PLOT_ID,Year)]

JPNATA<-fread("Export_Temp_JPN.csv")

JPNATA<-JPNATA[,.(PLOT_ID=Name,Year_Mon_Day=JPNATA$"Year-Month-Day",Temp=JPNATA$'Air Temperature')]#MeanAnnualTemp
right<-function(x,chr){return(substr(x,nchar(x)-chr+1,nchar(x)))}
JPNATA[,":="(Year=as.numeric(gsub("-.*","",Year_Mon_Day)),
             Mon_Day=as.character(right(Year_Mon_Day,5)))] %>% 
  .[,":="(Mon=as.numeric(gsub("-.*","",Mon_Day)),
          Day=as.character(right(Mon_Day,2)),
          PLOT_Y=paste(PLOT_ID,Year,sep="_"))]

#Calculate MAT
JPNATA<-JPNATA[,":="(MMT=mean(Temp)),by=,.(PLOT_ID,Year,Mon)] %>% #Mean Monthly Temp
  .[,":="(MAT=mean(Temp)),by=,.(PLOT_ID,Year)] %>% unique(by="PLOT_Y")

JPNATA[,MATave:=mean(MAT),by=PLOT_ID]#long-term average of MAT 2004-2018
JPNATA[,ATA:=MAT-MATave]

weath<-merge(JPNATA,JPNCMI,by=c("PLOT_ID","Year"))
setnames(weath,"PLOT_ID","GroupID")#"PLOT_ID" cannot be same as the name in jpn

data<-left_join(data,weath,by=c("MAIN_PLOT_ID"="GroupID", "yyyy"="Year"),suffix=c("","_y"))

data$ACMIA_scaled<-as.numeric(as.character(scale(data$ACMIA)))
data$ATA_scaled<-as.numeric(as.character(scale(data$ATA)))
data$APA_scaled<-as.numeric(as.character(scale(data$APA)))
data$CMIave_scaled<-as.numeric(as.character(scale(data$CMIave)))
data$MATave_scaled<-as.numeric(as.character(scale(data$MATave)))
data$MAPave_scaled<-as.numeric(as.character(scale(data$MAPave)))
data<-subset(data,season!="Winter") #only one or two samples.

####Land use variables#####

LU500<-read.csv(file="LU_500.csv")
LU1k<-read.csv(file="LU_1k.csv")
LU2k<-read.csv(file="LU_2k.csv")

LU1k<-LU1k[,c(5:20)]
LU2k<-LU2k[,c(5:20)]
LU500<-LU500[,c(5:20)]

sapply(1:ncol(LU500), function(i) cor(LU500[,i], LU1k[,i]))
sapply(1:ncol(LU500), function(i) cor(LU500[,i], LU2k[,i]))
sapply(1:ncol(LU500), function(i) cor(LU1k[,i], LU2k[,i]))

LU1k<-read.csv(file="LU_1k.csv")
LU1k$Forest.mean_1k<-(LU1k$X2006_forest+LU1k$X2009_forest+LU1k$X2014_forest+LU1k$X2016_forest)/4
LU1k$Urban.mean_1k<-(LU1k$X2006_urban+LU1k$X2009_urban+LU1k$X2014_urban+LU1k$X2016_urban)/4
LU1k$wasteland.mean_1k<-(LU1k$X2006_wasteland+LU1k$X2009_wasteland+LU1k$X2014_wasteland+LU1k$X2016_wasteland)/4
LU1k$farmland.mean_1k<-(LU1k$X2006_farm.land+LU1k$X2009_farm.land+LU1k$X2014_farm.land+LU1k$X2016_farm.land)/4
LU1k$landscape_het_1k<-diversity(LU1k[,c("Forest.mean_1k","Urban.mean_1k","wasteland.mean_1k","farmland.mean_1k")])
LU1k<-unique(LU1k[,c("MAIN_PLOT_ID","Forest.mean_1k","Urban.mean_1k","wasteland.mean_1k","farmland.mean_1k")])

LU500<-read.csv(file="LU_500.csv")
LU500$Forest.mean_500<-(LU500$X2006_forest+LU500$X2009_forest+LU500$X2014_forest+LU500$X2016_forest)/4
LU500$Urban.mean_500<-(LU500$X2006_urban+LU500$X2009_urban+LU500$X2014_urban+LU500$X2016_urban)/4
LU500$wasteland.mean_500<-(LU500$X2006_wasteland+LU500$X2009_wasteland+LU500$X2014_wasteland+LU500$X2016_wasteland)/4
LU500$farmland.mean_500<-(LU500$X2006_farm.land+LU500$X2009_farm.land+LU500$X2014_farm.land+LU500$X2016_farm.land)/4
LU500$landscape_het_500<-diversity(LU500[,c("Forest.mean_500","Urban.mean_500","wasteland.mean_500","farmland.mean_500")])
LU500<-unique(LU500[,c("MAIN_PLOT_ID","Forest.mean_500","Urban.mean_500","wasteland.mean_500","farmland.mean_500")])

LU2k<-read.csv(file="LU_2k.csv")
LU2k$Forest.mean_2k<-(LU2k$X2006_forest+LU2k$X2009_forest+LU2k$X2014_forest+LU2k$X2016_forest)/4
LU2k$Urban.mean_2k<-(LU2k$X2006_urban+LU2k$X2009_urban+LU2k$X2014_urban+LU2k$X2016_urban)/4
LU2k$wasteland.mean_2k<-(LU2k$X2006_wasteland+LU2k$X2009_wasteland+LU2k$X2014_wasteland+LU2k$X2016_wasteland)/4
LU2k$farmland.mean_2k<-(LU2k$X2006_farm.land+LU2k$X2009_farm.land+LU2k$X2014_farm.land+LU2k$X2016_farm.land)/4
LU2k$landscape_het_2k<-diversity(LU2k[,c("Forest.mean_2k","Urban.mean_2k","wasteland.mean_2k","farmland.mean_2k")])
LU2k<-unique(LU2k[,c("MAIN_PLOT_ID","Forest.mean_2k","Urban.mean_2k","wasteland.mean_2k","farmland.mean_2k")])

LU<-left_join(LU500,LU1k)
LU<-left_join(LU,LU2k)

cor(LU[,-1])

data<-left_join(data,LU)

data$Forest.mean_1k_scaled<-scale(data$Forest.mean_1k)
data$Urban.mean_1k_scaled<-scale(data$Urban.mean_1k)
data$farmland.mean_1k_scaled<-scale(data$farmland.mean_1k)

data$wasteland.mean_1k_scaled<-as.numeric(as.character(scale(data$wasteland.mean_1k)))
data$urban_factor<-ifelse(data$Urban.mean_1k>0.30, "urban","forest")
data$urban_factor

##################Deer variables###################
deer_data<-read.csv("JP_deer_data.csv")
deer_data<-deer_data[,c("MAIN_PLOT_ID","Deer_presence","Increase","Deer_veg_impact")]

data<-left_join(data,deer_data)
data$Deer_presence<-factor(data$Deer_presence)
data$Deer_increase<-factor(data$Increase)
data$Deer_veg_impact<-factor(data$Deer_veg_impact)

#####Carabid flight groups
trait_data<-read.csv(file="JP_species_list.csv")
carabid_trait<-subset(trait_data,fam=="Carabidae")

carabiddata<-data[,which(colnames(data) %in% carabid_trait$tax_no)]

carabids_fly<-carabiddata[,which(colnames(carabiddata) %in% subset(carabid_trait,Flight.ability =="1")$tax_no)]
carabids_flightless<-carabiddata[,which(colnames(carabiddata) %in% subset(carabid_trait,Flight.ability =="0")$tax_no)]

data$carabidfly_abundance<-rowSums(carabids_fly,na.rm=TRUE)
data$carabidfly_richness<-rowSums(carabids_fly>0,na.rm=TRUE)

data$carabidflightless_abundance<-rowSums(carabids_flightless,na.rm=TRUE)
data$carabidflightless_richness<-rowSums(carabids_flightless>0,na.rm=TRUE)

data$carabidfly_mass<-rowSums(data.frame(sweep(carabids_fly, MARGIN=2, trait_data[match(colnames(carabids_fly),trait_data$tax_no),]$mass_mean, `*`)),na.rm = TRUE)
data$carabidflightless_mass<-rowSums(data.frame(sweep(carabids_flightless, MARGIN=2, trait_data[match(colnames(carabids_flightless),trait_data$tax_no),]$mass_mean, `*`)),na.rm = TRUE)

data$carabids_fly_chaos<-estimateR(carabids_fly,datatype = "abundance")[2,]
data$carabids_flightless_chaos<-estimateR(carabids_flightless,datatype = "abundance")[2,]

########extras######

data$biomass_log<-log(1+data$beetle_biomass)
beetlespecies<-data[,c(which(colnames(data)=="10-1-1-2"):which(colnames(data)=="9-99-99-99"))]
data$chaoS <- estimateR(beetlespecies,datatype = "abundance")[2,]
data$chaoS <- round(data$chaoS, digits = 0)
save(data,file="JP_beetledata.RData")


#########################################################
######MAP##########################
load("JP_beetledata.RData")

japan_map <- map_data(map = "world", region="Japan")

#Modelling sites against MAP ave and MAT ave
nd<-data.frame(MAIN_PLOT_ID=levels(factor(data$MAIN_PLOT_ID)))

mod<-lm(MAPave~MAIN_PLOT_ID,data=data,na.action="na.omit")
pred_MAP<-cbind(nd,data.frame(MAP=predict(mod,newdata=nd)))

mod<-lm(MATave~MAIN_PLOT_ID,data=data,na.action="na.omit")
pred_MAT<-cbind(nd,data.frame(MAT=predict(mod,newdata=nd)))

PT<-left_join(pred_MAP,pred_MAT)
MLL<-unique(data[,c("MAIN_PLOT_ID","LAT","LONG","FT")])
PT<-left_join(PT,MLL)

axis_labels <- data.frame(x=125,y=seq(25,45, by=5))

jmap<-ggplot(data=japan_map,aes(x=jitter(long), y=lat) ) +
  geom_polygon(aes( group = group),alpha=1,fill="lightgreen")+
  theme(axis.text = element_text(colour="black"),
        axis.title.x = element_text(vjust=-1,colour="black"),
        axis.title.y = element_text(angle=90,vjust = 3),
        axis.ticks = element_line(colour="black"),
        panel.border = element_rect(colour = "black", fill=NA, size=0.5),
        legend.position="none",
        panel.grid.major = element_line(colour="lightgrey"),
        panel.grid.minor = element_line(colour="lightgrey"),
        panel.background = element_rect(fill="azure"))+
  geom_text_repel(data=PT,aes(label=MAIN_PLOT_ID,x=jitter(LONG), y=jitter(LAT)),size=2,box.padding = 0.4,segment.colour = "grey")+
  geom_point(data=PT, inherit.aes=F,aes(x=jitter(LONG), y=jitter(LAT),fill=FT,shape=FT,colour=FT),size=3,alpha=0.8)+
  geom_segment(x = 146, y = 28, xend = 146, yend = 30,
               arrow = arrow(length = unit(0.03, "npc"), ends = "last"),size=1.2)+
  geom_text(x = 146, y = 27.5, label="N")+
  scale_fill_viridis_d(direction=-1)+
  scale_colour_viridis_d(direction=-1)+
  xlab("Longitude (E)")+
  ylab("Latitude (N)")+
   coord_fixed()+
  xlim(127,146.5)+
  ylim(26,46)+
  scale_shape_manual(values=c(21:25),limits = c("Deciduous\nbroadleaf","Evergreen\nbroadleaf","Broadleaf/\nconiferous\nmixed","Evergreen\nconiferous"))+
  labs(fill = "Forest type",shape="Forest type")
  
jpeg(file ="japmap.jpeg", width = 4000, height = 4000, units = "px", res = 650) #this saves whatever you do next as an image. Skip this whilst just looking in R. use it to save a nice image of the plot (have a look in your working directory). 
jmap
dev.off()

#####climate plot for fig 1

climdat<-unique(data[,c("MAIN_PLOT_ID","MAPave","MATave","FT")])

mod<-lm(MAPave~MATave,data=climdat)
newdata = data.frame("MATave"=seq(min(climdat$MATave),max(climdat$MATave),length.out=100))
pc<-data.frame(predict(mod,newdata = newdata,type="response",se.fit=T))
pc<-cbind(newdata,pc)

climplot_small<-ggplot(data=climdat,  aes(x=MATave,y=MAPave,group=FT)) +
  geom_line(inherit.aes=F,data=pc,aes(x=MATave, y=fit))+
  geom_ribbon(inherit.aes=F,data=pc,aes(x=MATave, y=fit,ymin=fit-se.fit,ymax=fit+se.fit),fill="forestgreen",alpha=.1)+
  geom_point(aes(fill=FT,shape=FT,colour=FT),size=4,alpha=0.8)+
  ylab(expression(MAP[ave]~'(cm)'))+
  xlab(expression(MAT[ave]~'('^o*C*')'))+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="none",
        legend.key = element_blank(),
        legend.text = element_text(size=6),
        axis.text.y=element_text(color = "black", size = 8,hjust=0.5),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "centre")+
  scale_fill_viridis_d(direction=-1)+
  scale_colour_viridis_d(direction=-1)+
  scale_shape_manual(values=c(22,23,24,21,25))+
  labs(fill="Forest type",shape="Forest type",colour="Forest type")


climplot_small

png(file ="climplot_small.png", width = 9000, height = 8000, units = "px", res = 3050) #this saves whatever you do next as an image. Skip this whilst just looking in R. use it to save a nice image of the plot (have a look in your working directory). 
climplot_small
dev.off()

########################################
######Boxplots############## 

data$YS<-paste0(data$yyyy,"_",data$season)

data$FT_alt<-data$FT

data$FT_alt<-revalue(data$FT,c("Broadleaf/\nconiferous\nmixed"="Broadleaf\nconiferous\nmixed"))

bp_richness<-ggplot(data=data,aes(x=date_cont, y=richness,group=1))+
  stat_summary_bin(data=data,aes(x=date_cont, y=richness,group=season,colour=season,shape=season),fun.data = "mean_cl_boot",fun.args=list(conf.int=.95),
                   bins=100,size=0.5)+
  geom_smooth(data=data,method='lm',formula=y~x)+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_rect(fill = "white", colour = "white"),
        plot.background = element_rect(fill = "white", colour = "white"),
        legend.background = element_rect(fill = "white", colour = "white"),
        legend.key = element_rect(fill = "white", colour = "white"),
        panel.border=element_blank(),
        plot.margin = unit(c(0,1,0.5,0), "lines"),
        text=element_text(colour="black"),
        strip.background = element_blank(),
        axis.text.y=element_text(angle=0, vjust=0.5,color="black"),
        axis.text.x=element_text(color="black",size=10))+
  xlab("Year")+
  ylab("Richness")+
  scale_y_continuous(trans = "log1p")+
  scale_x_continuous(breaks=seq(2006,2018,3))+
  scale_shape_manual(values=c(16:18))+
  scale_colour_viridis_d(option="D",begin=0.3,end=0.9)+
  facet_grid(.~FT_alt,scales="free")+
  labs(fill="Season", colour="Season",shape="Season")+
  guides( linetype="none") 

bp_chaos<-ggplot(data=data,aes(x=date_cont, y=chaoS,group=1))+
  stat_summary_bin(data=data,aes(x=date_cont, y=chaoS,group=season,colour=season,shape=season),fun.data = "mean_cl_boot",fun.args=list(conf.int=.95),
                   bins=100,size=0.5)+
  geom_smooth(data=data,method='lm',formula=y~x)+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_rect(fill = "white", colour = "white"),
        plot.background = element_rect(fill = "white", colour = "white"),
        legend.background = element_rect(fill = "white", colour = "white"),
        legend.key = element_rect(fill = "white", colour = "white"),
        panel.border=element_blank(),
        plot.margin = unit(c(0,1,0.50,0), "lines"),
        text=element_text(colour="black"),
        strip.background = element_blank(),
        axis.text.y=element_text(angle=0, vjust=0.5,color="black"),
        axis.text.x=element_text(color="black",size=10))+
  xlab("Year")+
  ylab("Chao's S")+
  scale_y_continuous(trans = "log1p")+
  scale_x_continuous(breaks=seq(2006,2018,3))+
  scale_shape_manual(values=c(16:18))+
  scale_colour_viridis_d(option="D",begin=0.3,end=0.9)+
  facet_grid(.~FT_alt,scales="free")+
  labs(fill="Season", colour="Season",shape="Season")+
  guides( linetype="none") 
bp_chaos


bp_abundance<-ggplot(data=data,aes(x=date_cont, y=abundance,group=1))+
  stat_summary_bin(data=data,aes(x=date_cont, y=abundance,group=season,colour=season,shape=season),fun.data = "mean_cl_boot",fun.args=list(conf.int=.95),
                   bins=100,size=0.5)+
  geom_smooth(data=data,method='lm',formula=y~x)+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_rect(fill = "white", colour = "white"),
        plot.background = element_rect(fill = "white", colour = "white"),
        legend.background = element_rect(fill = "white", colour = "white"),
        legend.key = element_rect(fill = "white", colour = "white"),
        panel.border=element_blank(),
        plot.margin = unit(c(0,1,0.5,0), "lines"),
        text=element_text(colour="black"),
        strip.background = element_blank(),
        axis.text.y=element_text(angle=0, vjust=0.5,color="black"),
        axis.text.x=element_text(color="black",size=10))+
  xlab("Year")+
  ylab("Abundance")+
  scale_y_continuous(trans = "log1p")+
  scale_x_continuous(breaks=seq(2006,2018,3))+
  scale_shape_manual(values=c(16:18))+
  scale_colour_viridis_d(option="D",begin=0.3,end=0.9)+
  facet_grid(.~FT_alt,scales="free")+
  labs(fill="Season", colour="Season",shape="Season")+
  guides( linetype="none") 


bp_biomass<-ggplot(data=data,aes(x=date_cont, y=beetle_biomass,group=1))+
  stat_summary_bin(data=data,aes(x=date_cont, y=beetle_biomass,group=season,colour=season,shape=season),fun.data = "mean_cl_boot",fun.args=list(conf.int=.95),
                   bins=100,size=0.5)+
  geom_smooth(data=data,method='lm',formula=y~x)+
  theme(axis.line = element_line(colour = "black"),
        panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_rect(fill = "white", colour = "white"),
        plot.background = element_rect(fill = "white", colour = "white"),
        legend.background = element_rect(fill = "white", colour = "white"),
        legend.key = element_rect(fill = "white", colour = "white"),
        panel.border=element_blank(),
        text=element_text(colour="black"),
        strip.background = element_blank(),
        plot.margin = unit(c(0,1,0.5,0), "lines"),
        axis.text.y=element_text(angle=0, vjust=0.5,color="black"),
        axis.text.x=element_text(color="black",size=8))+
  xlab("Year")+
  ylab("Biomass (kg)")+
  scale_y_continuous(trans = "log1p",breaks=c(0,250,1000,5000,15000),labels=c("0","0.25","1","5","15"))+
  scale_x_continuous(breaks=seq(2006,2018,3))+
  scale_shape_manual(values=c(16:18))+
  scale_colour_viridis_d(option="D",begin=0.3,end=0.9)+
  facet_grid(.~FT_alt,scales="free")+
  labs(fill="Season", colour="Season",shape="Season")+
  guides( linetype="none") 

bp_biomass

bps<-ggarrange(bp_richness,bp_chaos,bp_abundance,bp_biomass,ncol=1,nrow=4,common.legend = TRUE, legend="right",align="hv")

theme_top<-theme(axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.x = element_blank(),axis.line.x = element_blank())
theme_middle<-theme(axis.text.x = element_blank(),axis.ticks.x = element_blank(),axis.title.x = element_blank(),strip.text = element_blank(),axis.line.x = element_blank())
theme_bottom<-theme(strip.text = element_blank())

bps_cond<-ggarrange(bp_richness+theme_top,
                    bp_chaos+theme_middle,
                    bp_abundance+theme_middle,
                    bp_biomass+theme_bottom,
                    ncol=1,nrow=4,common.legend = TRUE,heights=c(1.2,1,1,1.2), legend="bottom",align="v")

bps_cond

ggsave(filename = "Fig_2.pdf", 
                plot = bps_cond, 
                device = "pdf", 
                dpi = 600, 
                width = 173,
                height = 200, 
                units = "mm")

###################Models against time############################
cor(data[,c("Forest.mean_1k_scaled","Urban.mean_1k_scaled","farmland.mean_1k_scaled","wasteland.mean_1k_scaled")])
data$biomass_log<-log(1+data$beetle_biomass)
data$urban_factor<-ifelse(data$Urban.mean_1k>0.30, "urban","forest")
data$urban_factor

mod1<-glmmTMB(chaoS~
                    ForestType*yyyy_scaled+
                    urban_factor*yyyy_scaled+
                    farmland.mean_1k_scaled*yyyy_scaled+
                    Deer_veg_impact*yyyy_scaled+
                    offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

mod2<-glmmTMB(richness~
                    ForestType*yyyy_scaled+
                    urban_factor*yyyy_scaled+
                    farmland.mean_1k_scaled*yyyy_scaled+
                    Deer_veg_impact*yyyy_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod3<-glmmTMB(abundance~
                ForestType*yyyy_scaled+
                urban_factor*yyyy_scaled+
                farmland.mean_1k_scaled*yyyy_scaled+
                Deer_veg_impact*yyyy_scaled+
                offset(days)+
                (1|Site_Name/MAIN_PLOT_ID) + (1|season),
              data=data,na.action="na.fail",family="nbinom2",REML=F)

mod4<-glmmTMB(biomass_log~
                    ForestType*yyyy_scaled+
                    urban_factor*yyyy_scaled+
                    farmland.mean_1k_scaled*yyyy_scaled+
                    Deer_veg_impact*yyyy_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#############################effects plots over time
########################################

effects_timemods<-data.frame()
for(i in c(1:4)) {
  
  effects<-data.frame(summary(get(paste0("mod",i)))$coef$cond)
  colnames(effects)[length(colnames(effects))]<-"p_value"
  effects$response<-as.character(formula(get(paste0("mod",i)),fixed.only=TRUE,component="cond"))[2]
  effects$dist<-summary(get(paste0("mod",i)))$family
  effects$level<-row.names(effects)
  effects_timemods<-smartbind(effects_timemods,effects)
  
}

effects<-effects_timemods
effects$lower<-(effects$Estimate-effects$Std..Error*1.96)
effects$upper<-(effects$Estimate+effects$Std..Error*1.96)
effects$group<-revalue(effects$response, c("abundance"="Abundance",
                                    "richness"="Richness",
                                    "biomass_log"="Biomass",
                                    "chaoS"= "Chao's S"))
effects$level <- str_replace_all(effects$level, 'yyyy_scaled', 'Time')
effects$level <- str_replace_all(effects$level, 'ForestType', '')
effects$level <- str_replace_all(effects$level, 'urban_factorurban', 'Urban')
effects$level <- str_replace_all(effects$level, 'farmland.mean_1k_scaled', 'Farmland')
effects$level <- str_replace_all(effects$level, 'MATave_scaled', "MAT")
effects$level <- str_replace_all(effects$level, 'Deer_presence1', 'Deer presence')
effects$level <- str_replace_all(effects$level, 'Deer_veg_impact1', 'Deer impacts')
effects$level <- str_replace_all(effects$level, 'MAT:Time', 'Time:MAT')
effects$level <- str_replace_all(effects$level, 'BC:Time', 'Time:BC')
effects$level <- str_replace_all(effects$level, 'EC:Time', 'Time:EC')
effects$level <- str_replace_all(effects$level, 'DB:Time', 'Time:DB')
effects$level <- str_replace_all(effects$level, 'Deer impacts:Time', 'Time:Deer impacts')
effects$level <- str_replace_all(effects$level, 'Deer presence:Time', 'Time:Deer presence')
effects$level <- str_replace_all(effects$level, 'Urban:Time', 'Time:Urban')
effects$level <- str_replace_all(effects$level, 'EC', 'Evergreen coniferous')
effects$level <- str_replace_all(effects$level, 'DB', 'Deciduous broadleaf')
effects$level <- str_replace_all(effects$level, 'BC', 'Broadleaf coniferous mixed')
effects$level <- str_replace_all(effects$level, 'MAT', 'Mean annual temperature')

effects$int<-"Fixed\neffects"
effects$int[which(str_detect(effects$level,":"))]<-"Interactive\neffects"

effects$group<-fct_rev(factor(effects$group,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$level<-fct_rev(factor(effects$level,levels=c("Time","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                             "Time:Mean annual temperature","Time:Evergreen coniferous","Time:Deciduous broadleaf","Time:Broadleaf coniferous mixed","Time:Urban","Time:Farmland",
                                             "Time:Deer impacts")))

effects_sub<-subset(effects,level!="(Intercept)")
effects_sub$p_value<-ifelse(effects_sub$p_value<0.00001,0.00001,effects_sub$p_value)

subd<-levels(factor(effects_sub$int))

for( i in c(1,2)) {
  assign(paste0("plot", i),ggplot(data=subset(effects_sub, int==subd[i]),  aes(x=Estimate,y=group)) +
           geom_vline(xintercept=0,linetype=2,colour="black")+
           geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),position=position_dodge(0.8),height=0)+
           geom_point(aes(group=response,shape=response),fill="white", col="white",position=position_dodge(0.8),size=3)+
           geom_point(aes(fill=response,group=response,alpha=p_value,shape=response),col="transparent",position=position_dodge(0.8),size=3)+
           geom_vline(xintercept=0,linetype=2,colour="black")+
           xlab("Estimates")+
           ylab("")+
           theme(panel.grid.major = element_blank(),
                 panel.grid.minor = element_blank(),
                 panel.background = element_blank(),
                 panel.border=element_blank(),
                 axis.line=element_line(),
                 strip.background =element_blank(),
                 panel.spacing = unit(0.5,"lines"),
                 strip.text = element_text(size=7),
                  text=element_text(size=12,colour="black"),
                 legend.position="bottom",
                 legend.key = element_blank(),
                 legend.text=element_text(size=6),
                 axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
                 axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
                 legend.justification = "top")+
           scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
           scale_fill_viridis_d()+
           scale_colour_viridis_d()+
           scale_shape_manual(values=c(21,23,24,25))+
           facet_grid(int~level,scales="free",labeller=labeller(level = label_wrap_gen(20)))+
           labs(colour="Metric",fill="Metric",size="P value",alpha="P value",shape="Metric"))
  }

effects_plot_time<-ggarrange(plot1,plot2,labels = c("A.","B."), ncol=1,common.legend = TRUE,legend="bottom")
effects_plot_time


png(filename = "effects_mod1.png", width = 6000, height =2000, units = "px",res = 600)
effects_plot_time
dev.off()


other_effects<-subset(effects_sub, level %in% c("Time:Mean annual temperature", "Time:Urban","Time:Farmland","Time:Deer impacts"))
other_effects$level <- str_replace_all(other_effects$level, 'Time:Farmland', 'Time:Farmland')
other_effects$response<-fct_rev(factor(other_effects$group,levels=c("Richness","Chao's S","Abundance","Biomass")))
other_effects$level<-factor(other_effects$level,levels=c("Time:Deer impacts","Time:Urban","Time:Farmland","Time:Mean annual temperature"))

effects_other_emtrends<-ggplot(data=other_effects,  aes(x=Estimate,y=response)) +

  geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),height=0)+
  geom_col(aes(fill=response,alpha=p_value))+
  geom_vline(xintercept=0,linetype=2,colour="black")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        panel.spacing = unit(0.5,"lines"),
       # text=element_text(size=12,colour="black"),
        legend.position="bottom",
        legend.spacing = unit(1,"cm"),
        legend.key = element_blank(),
        legend.text=element_text(size=8),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        legend.justification = "top")+
  scale_fill_viridis_d(option="D")+
  scale_colour_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  facet_grid(.~level,space="free",scale="free")+
  scale_x_continuous(breaks=c(seq(-0.5,0.6, 0.1)))+
  labs(colour="",fill="",alpha="P value")+
  guides(size="none",
         fill=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         colour=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         alpha=guide_legend(title.position = "top",title.hjust = 0.5,reverse=T))

png(filename = "othertimeeffects.png", width = 7000, height =2500, units = "px",res = 800)
effects_other_emtrends
dev.off()

ct<-test(emtrends(mod1, pairwise ~ ForestType, var = "yyyy_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Chao's S"
ForCont<-ct

ct<-test(emtrends(mod2, pairwise ~ ForestType, var = "yyyy_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Richness"
ForCont<-rbind(ForCont,ct)

ct<-test(emtrends(mod2, pairwise ~ ForestType, var = "yyyy_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Abundance"
ForCont<-rbind(ForCont,ct)

ct<-test(emtrends(mod4, pairwise ~ ForestType, var = "yyyy_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Biomass"
ForCont<-rbind(ForCont,ct)

######effect sizes#####
ct<-test(emtrends(mod1, pairwise ~ ForestType, var = "yyyy_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Chao's S"
Foreff<-ef

ct<-test(emtrends(mod2, pairwise ~ ForestType, var = "yyyy_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Richness"
Foreff<-rbind(Foreff,ef)

ct<-test(emtrends(mod2, pairwise ~ ForestType, var = "yyyy_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Abundance"
Foreff<-rbind(Foreff,ef)

ct<-test(emtrends(mod4, pairwise ~ ForestType, var = "yyyy_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Biomass"
Foreff<-rbind(Foreff,ef)

effects<-Foreff
effects$ForestType <- str_replace_all(effects$ForestType, 'EC', 'Time:Evergreen\nconiferous')
effects$ForestType <- str_replace_all(effects$ForestType, 'DB', 'Time:Deciduous\nbroadleaf')
effects$ForestType <- str_replace_all(effects$ForestType, 'BC', 'Time:Broadleaf\nconiferous\nmixed')
effects$ForestType <- str_replace_all(effects$ForestType, 'EB', 'Time:Evergreen\nbroadleaf')
effects$ForestType<-factor(effects$ForestType,levels=c("Time:Evergreen\nbroadleaf",
                                                       "Time:Broadleaf\nconiferous\nmixed",
                                                       "Time:Evergreen\nconiferous",
                                                       "Time:Deciduous\nbroadleaf"))

effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$lower<-effects$yyyy_scaled.trend-(1.96*effects$SE)
effects$upper<-effects$yyyy_scaled.trend+(1.96*effects$SE)
effects_forest_emtrends<-ggplot(data=effects,  aes(x=yyyy_scaled.trend,y=response)) +

  geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p.value),height=0)+
  geom_col(aes(fill=response,alpha=p.value))+
  geom_vline(xintercept=0,linetype=2,colour="black")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        panel.spacing = unit(0.5,"lines"),
        #text=element_text(size=12,colour="black"),
        legend.position="bottom",
        legend.spacing = unit(1,"cm"),
        legend.key = element_blank(),
        legend.text=element_text(size=8),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        legend.justification = "top")+
  scale_fill_viridis_d(option="D")+
  scale_colour_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  facet_grid(.~ForestType,space="free",scale="free")+
  scale_x_continuous(breaks=c(seq(-0.5,0.6, 0.1)))+
  labs(colour="",fill="",alpha="P value")+
  guides(size="none",
         fill=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         colour=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         alpha=guide_legend(title.position = "top",title.hjust = 0.5,reverse=T))

png(filename = "foresttimeeffects.png", width = 7000, height =2200, units = "px",res = 800)
effects_forest_emtrends
dev.off()

main_interactive_effects_plot<-ggarrange(effects_forest_emtrends, effects_other_emtrends, ncol=1,labels=c("A.","B."),heights=c(1,0.9),common.legend = T,legend="bottom")
main_interactive_effects_plot

png(filename = "main_interactive_effects_plot.png", width = 7000, height =4000, units = "px",res = 1000)
main_interactive_effects_plot
dev.off()

ggsave(filename = "Fig_3.pdf", 
       plot = main_interactive_effects_plot, 
       device = "pdf", 
       dpi = 600, 
       width = 173,
       height = 110, 
       units = "mm")

#####Forest x time #predictions
preddata<-seq(min(data$yyyy_scaled),max(data$yyyy_scaled),length.out=25)

pred<-ggpredict(mod1,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted
pred<-data.frame(pred)
pred$metric<-"Chao's S"
pd<-pred

pred<-ggpredict(mod2,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted
pred<-data.frame(pred)
pred$metric<-"Richness"
pd<-smartbind(pd,pred)

pred<-ggpredict(mod3,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted
pred<-data.frame(pred)
pred$metric<-"Abundance"
pd<-smartbind(pd,pred)

pred<-ggpredict(mod4,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted<-exp(pred$predicted)-1
pred$conf.high<-exp(pred$conf.high)-1
pred$conf.low<-exp(pred$conf.low)-1
pred<-data.frame(pred)
pred$metric<-"Biomass"
pd<-smartbind(pd,pred)

pd$metric<-factor(pd$metric,levels=c("Richness","Chao's S","Abundance","Biomass"))
pd$FT<-revalue(pd$group,c("EB"="Evergreen\nbroadleaf","BC"="Broadleaf\nconiferous\nmixed","EC"="Evergreen\nconiferous","DB"="Deciduous\nbroadleaf"))

pd_forest<-pd

forest_time_plot<-ggplot(pd_forest, aes(year, predicted,group=FT)) +
    geom_line(aes(group=FT,col=FT),size=1) +
    theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        legend.position="bottom",
        legend.key = element_blank(),
        legend.box.spacing = unit(0, "lines"),
        legend.spacing = unit(0,"lines"),
        legend.key.width = unit(4,"lines"),
        legend.key.height = unit(0.14,"lines"),
        legend.box.margin = margin(0,0,0,0),
        legend.text=element_text(size=8,margin = margin(r = 3, unit = "lines")),
        legend.title = element_blank(),
        panel.spacing.x=unit(0, "lines"),
        text=element_text(colour="black"),
        legend.title.align = 0.5,
        legend.box="horizontal",
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        axis.text=element_text(colour="black",size=8),
        legend.justification = "centre")+
  scale_color_viridis_d()+
  scale_x_continuous(breaks=c(seq(2005,2018,3)))+
  ylab("")+
  xlab("Year")+
  facet_wrap(metric~.,scales="free_y",ncol = 4)+
  labs(colour="Forest type",fill="Forest type")+
  guides(colour = guide_legend(title.position="top", title.hjust = 0.5))

Fig3<-ggarrange(effects_forest_emtrends,effects_other_emtrends, ncol=1,labels=c("A.","B."),heights=c(1,0.9),common.legend = TRUE,legend= "bottom")

png(filename = "Fig3.png", width = 6500, height =4000, units = "px",res = 900)
Fig3
dev.off()


#####Forest x time #predictions
preddata<-seq(min(data$yyyy_scaled),max(data$yyyy_scaled),length.out=25)

pred<-ggpredict(mod1,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted
pred<-data.frame(pred)
pred$metric<-"Chao's S"
pd<-pred

pred<-ggpredict(mod2,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted
pred<-data.frame(pred)
pred$metric<-"Richness"
pd<-smartbind(pd,pred)

pred<-ggpredict(mod3,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted
pred<-data.frame(pred)
pred$metric<-"Abundance"
pd<-smartbind(pd,pred)

pred<-ggpredict(mod4,terms=c("yyyy_scaled [preddata]","ForestType"),ci.lvl = 0.68)
pred$year<-scales::rescale(pred$x,to=c(2005,2018))
pred$predicted<-exp(pred$predicted)-1
pred$conf.high<-exp(pred$conf.high)-1
pred$conf.low<-exp(pred$conf.low)-1
pred<-data.frame(pred)
pred$metric<-"Biomass"
pd<-smartbind(pd,pred)

pd$metric<-factor(pd$metric,levels=c("Richness","Chao's S","Abundance","Biomass"))
pd$FT<-revalue(pd$group,c("EB"="Evergreen\nbroadleaf","BC"="Broadleaf\nconiferous\nmixed","EC"="Evergreen\nconiferous","DB"="Deciduous\nbroadleaf"))

pd_forest<-pd

forest_time_plot<-ggplot(pd_forest, aes(year, predicted,group=FT)) +
  geom_line(aes(group=FT,col=FT),size=2) +
  geom_ribbon(aes(ymin = conf.low, ymax = conf.high,fill=FT), alpha = .1)+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.title.align = 0.5,
        legend.box="horizontal",
        legend.key = element_blank(),
        legend.position = "right",
        axis.text.y=element_markdown(color = "black", size = 8,hjust=0.5),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        panel.spacing = unit(0, "lines"),
        legend.justification = "centre")+
  scale_color_viridis_d()+
  scale_x_continuous(breaks=c(seq(2005,2018,3)))+
  ylab("")+
  xlab("Year")+
  facet_wrap(metric~.,scales="free_y",ncol = 4)+
  labs(colour="Forest type",fill="Forest type")+
  guides(colour = guide_legend(title.position="top", title.hjust = 0.5))

######Feeding guilds over time#############
###############################
#Predators
data$response<-data$`Predators (Chao's S)`
modpre1<-glmmTMB(response~
                ForestType*yyyy_scaled+
                urban_factor*yyyy_scaled+
                farmland.mean_1k_scaled*yyyy_scaled+
                Deer_veg_impact*yyyy_scaled+
                offset(days)+
                offset(days)+
                (1|Site_Name/MAIN_PLOT_ID) + (1|season),
              data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$`Predators (richness)`
modpre2<-glmmTMB(response~
                ForestType*yyyy_scaled+
                urban_factor*yyyy_scaled+
                farmland.mean_1k_scaled*yyyy_scaled+
                Deer_veg_impact*yyyy_scaled+
                offset(days)+
                (1|Site_Name/MAIN_PLOT_ID) + (1|season),
              data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$`Predators (abundance)`
modpre3<-glmmTMB(response~
                ForestType*yyyy_scaled+
                urban_factor*yyyy_scaled+
                farmland.mean_1k_scaled*yyyy_scaled+
                Deer_veg_impact*yyyy_scaled+
                offset(days)+
                (1|Site_Name/MAIN_PLOT_ID) + (1|season),
              data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Predators (biomass)`+1)
modpre4<-glmmTMB(response~
                ForestType*yyyy_scaled+
                urban_factor*yyyy_scaled+
                farmland.mean_1k_scaled*yyyy_scaled+
                Deer_veg_impact*yyyy_scaled+
                offset(days)+
                (1|Site_Name/MAIN_PLOT_ID) + (1|season),
              data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#Saprophagous
data$response<-data$`Saprophages (Chao's S)`
modsap1<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2")

data$response<-data$`Saprophages (richness)`
modsap2<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="poisson")

data$response<-data$`Saprophages (abundance)`
modsap3<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",REML=F)

data$response<-log(data$`Saprophages (biomass)`+1)
modsap4<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)


#Carabids
data$response<-data$`Carabidae (Chao's S)`
modcarab1<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$Carabidae_richness
modcarab2<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$Carabidae_abundance
modcarab3<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Carabidae (biomass)`+1)
modcarab4<-glmmTMB(response~
                   ForestType*yyyy_scaled+
                   urban_factor*yyyy_scaled+
                   farmland.mean_1k_scaled*yyyy_scaled+
                   Deer_veg_impact*yyyy_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###Staphylindae
data$response<-data$`Staphylinidae (Chao's S)`
modstaphy1<-glmmTMB(response~
                     ForestType*yyyy_scaled+
                     urban_factor*yyyy_scaled+
                     farmland.mean_1k_scaled*yyyy_scaled+
                     Deer_veg_impact*yyyy_scaled+
                     offset(days)+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,control=glmmTMBControl(optimizer=optim,
                                                                                                        optArgs=list(method="BFGS")))

data$response<-data$Staphylinidae_richness
modstaphy2<-glmmTMB(response~
                     ForestType*yyyy_scaled+
                     urban_factor*yyyy_scaled+
                     farmland.mean_1k_scaled*yyyy_scaled+
                     Deer_veg_impact*yyyy_scaled+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F,control=glmmTMBControl(optimizer=optim,
                                                                                                               optArgs=list(method="BFGS")))

data$response<-data$Staphylinidae_abundance
modstaphy3<-glmmTMB(response~
                     ForestType*yyyy_scaled+
                     urban_factor*yyyy_scaled+
                     farmland.mean_1k_scaled*yyyy_scaled+
                     Deer_veg_impact*yyyy_scaled+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Staphylinidae (biomass)`+1)
modstaphy4<-glmmTMB(response~
                     ForestType*yyyy_scaled+
                     urban_factor*yyyy_scaled+
                     farmland.mean_1k_scaled*yyyy_scaled+
                     Deer_veg_impact*yyyy_scaled+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###Silphidae
data$response<-data$`Silphidae (Chao's S)`
modsilphid1<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2")

data$response<-data$Silphidae_richness
modsilphid2<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="poisson")

data$response<-data$Silphidae_abundance
modsilphid3<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Silphidae (biomass)`+1)
modsilphid4<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###GEOTRUPIDAE
data$response<-data$`Geotrupidae (Chao's S)`
modgeotrup1<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="poisson",ziformula = ~1)

data$response<-data$Geotrupidae_richness
modgeotrup2<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="poisson",ziformula = ~1)

data$response<-data$Geotrupidae_abundance
modgeotrup3<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Geotrupidae (biomass)`+1)
modgeotrup4<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)


#########################################################
#####Carabid analysis################

###########modelling########################################

###can fly
modcarfly1<-glmmTMB(carabids_fly_chaos~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2")

modcarfly2<-glmmTMB(carabidfly_richness~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="poisson")

modcarfly3<-glmmTMB(carabidfly_abundance~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-log(data$carabidfly_mass+1)
modcarfly4<-glmmTMB(response~
                      ForestType*yyyy_scaled+
                      urban_factor*yyyy_scaled+
                      farmland.mean_1k_scaled*yyyy_scaled+
                      Deer_veg_impact*yyyy_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="gaussian",REML=F)

###flightless########

modcarflightless1<-glmmTMB(carabids_flightless_chaos~
                             ForestType*yyyy_scaled+
                             urban_factor*yyyy_scaled+
                             farmland.mean_1k_scaled*yyyy_scaled+
                             Deer_veg_impact*yyyy_scaled+
                             offset(days)+
                             offset(days)+
                             (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                           data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

modcarflightless2<-glmmTMB(carabidflightless_richness~
                           ForestType*yyyy_scaled+
                             urban_factor*yyyy_scaled+
                             farmland.mean_1k_scaled*yyyy_scaled+
                             Deer_veg_impact*yyyy_scaled+
                             offset(days)+
                             (1|Site_Name) + (1|season),
                           data=data,na.action="na.fail",family="nbinom2")

modcarflightless3<-glmmTMB(carabidflightless_abundance~
                             ForestType*yyyy_scaled+
                             urban_factor*yyyy_scaled+
                             farmland.mean_1k_scaled*yyyy_scaled+
                             Deer_veg_impact*yyyy_scaled+
                             offset(days)+
                             (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                           data=data,na.action="na.fail",family="nbinom2", ,ziformula = ~1)

data$response<-log(data$carabidflightless_mass+1)
modcarflightless4<-glmmTMB(response~
                             ForestType*yyyy_scaled+
                             urban_factor*yyyy_scaled+
                             farmland.mean_1k_scaled*yyyy_scaled+
                             Deer_veg_impact*yyyy_scaled+
                             offset(days)+
                             (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                           data=data,na.action="na.fail",family="gaussian",REML=F)

####Group mods
modlist=expand.grid("model"=c("modpre","modsap","modcarab","modstaphy","modsilphid","modgeotrup","modcarfly","modcarflightless"),"num"=seq(1,4,1))
modlist$name<-paste0(modlist$model,modlist$num)
modlist$metric<-str_replace_all(modlist$num, '1', "Chao's S")
modlist$metric<-str_replace_all(modlist$metric, '2', "Richness")
modlist$metric<-str_replace_all(modlist$metric, '3', "Abundance")
modlist$metric<-str_replace_all(modlist$metric, '4', "Biomass")
effects_groupmods<-data.frame()

for(i in c(1:length(modlist$model))) {
  effects<-data.frame(summary(get(paste(modlist$name[i])))$coef$cond)
  colnames(effects)[length(colnames(effects))]<-"p_value"
  effects$response<-modlist$metric[i]
  effects$mod<-modlist$name[i]
  effects$level<-row.names(effects)
  effects_groupmods<-smartbind(effects_groupmods,effects)
  }

#####plotting 

effects<-effects_groupmods
effects$lower<-(effects$Estimate-effects$Std..Error*1.96)
effects$upper<-(effects$Estimate+effects$Std..Error*1.96)

effects$level <- str_replace_all(effects$level, 'yyyy_scaled', 'Time')
effects$level <- str_replace_all(effects$level, 'ForestType', '')
effects$level <- str_replace_all(effects$level, 'urban_factorurban', 'Urban')
effects$level <- str_replace_all(effects$level, 'farmland.mean_1k_scaled', 'Farmland')
effects$level <- str_replace_all(effects$level, 'MATave_scaled', "MAT")
effects$level <- str_replace_all(effects$level, 'Deer_presence1', 'Deer presence')
effects$level <- str_replace_all(effects$level, 'Deer_veg_impact1', 'Deer impacts')
effects$level <- str_replace_all(effects$level, 'MAT:Time', 'Time:MAT')
effects$level <- str_replace_all(effects$level, 'BC:Time', 'Time:BC')
effects$level <- str_replace_all(effects$level, 'EC:Time', 'Time:EC')
effects$level <- str_replace_all(effects$level, 'DB:Time', 'Time:DB')
effects$level <- str_replace_all(effects$level, 'Deer impacts:Time', 'Time:Deer impacts')
effects$level <- str_replace_all(effects$level, 'Deer presence:Time', 'Time:Deer presence')
effects$level <- str_replace_all(effects$level, 'Urban:Time', 'Time:Urban')
effects$level <- str_replace_all(effects$level, 'EC', 'Evergreen coniferous')
effects$level <- str_replace_all(effects$level, 'DB', 'Deciduous broadleaf')
effects$level <- str_replace_all(effects$level, 'BC', 'Broadleaf coniferous mixed')
effects$level <- str_replace_all(effects$level, 'MAT', 'Mean annual temperature')
effects$group<-str_replace_all(effects$mod, 'modsap', 'Saprophages')
effects$group<-str_replace_all(effects$group, 'modpre', 'Predators')
effects$group<-str_replace_all(effects$group, 'modcarab', 'Carabidae')
effects$group<-str_replace_all(effects$group, 'modstaphy', 'Staphylinidae')
effects$group<-str_replace_all(effects$group, 'modsilphid', 'Silphidae')
effects$group<-str_replace_all(effects$group, 'modgeotrup', 'Geotrupidae')
effects$group<-str_replace_all(effects$group, 'modcarfly', 'Flight-capable Carabidae')
effects$group<-str_replace_all(effects$group, 'modcarflightless', 'Flightless Carabidae')
effects$group<-str_replace(effects$group, "[:digit:]","")

effects$int<-"Fixed\neffects"
effects$int[which(str_detect(effects$level,":"))]<-"Interactive\neffects"
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$level<-fct_rev(factor(effects$level,levels=c("Time","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "Time:Mean annual temperature","Time:Evergreen coniferous","Time:Deciduous broadleaf","Time:Broadleaf coniferous mixed","Time:Urban","Time:Farmland",
                                                     "Time:Deer impacts")))

effects$group<-factor(effects$group,levels=c("Silphidae","Geotrupidae","Staphylinidae","Flightless Carabidae","Flight-capable Carabidae","Carabidae","Saprophages","Predators"))
effects_sub<-subset(effects,level!="(Intercept)")
effects_sub$p_value<-ifelse(effects_sub$p_value<0.00001,0.00001,effects_sub$p_value)
subd<-levels(factor(effects_sub$int))

for( i in c(1,2)) {
  assign(paste0("plot", i),ggplot(data=subset(effects_sub, int==subd[i]),  aes(x=Estimate,y=group)) +
           geom_vline(xintercept=0,linetype=2,colour="black")+
           geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),position=position_dodge(0.8),height=0)+
           geom_point(aes(group=response,shape=response),fill="white", col="white",position=position_dodge(0.8),size=2)+
           geom_point(aes(fill=response,group=response,alpha=p_value,shape=response),col="transparent",position=position_dodge(0.8),size=2)+
           
           geom_vline(xintercept=0,linetype=2,colour="black")+
           xlab("Estimates")+
           ylab("")+
           theme(panel.grid.major = element_blank(),
                 panel.grid.minor = element_blank(),
                 panel.background = element_blank(),
                 panel.border=element_blank(),
                 axis.line=element_line(),
                 strip.background =element_blank(),
                 panel.spacing = unit(0.5,"lines"),
                 strip.text = element_text(size=7),
                  text=element_text(size=12,colour="black"),
                 legend.position="bottom",
                 legend.key = element_blank(),
                 legend.text=element_text(size=6),
                 axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
                 axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
                     legend.justification = "top")+
          scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
           scale_fill_viridis_d()+
           scale_colour_viridis_d()+
           scale_shape_manual(values=c(21,23,24,25))+
           facet_grid(int~level,scales="free",labeller=labeller(level = label_wrap_gen(20)))+
           labs(colour="Metric",fill="Metric",size="P value",alpha="P value",shape="Metric"))
}


effects_plot_time_groups<-ggarrange(plot1,plot2,labels = c("A.","B."), ncol=1,common.legend = TRUE,legend="bottom")

png(filename = "effects_plot_groups.png", width = 7000, height =5000, units = "px",res = 600)
effects_plot_time_groups
dev.off()


#####to get marginal effects of factor levels

modlist=expand.grid("model"=c("modpre","modsap","modcarab","modstaphy","modsilphid","modgeotrup","modcarfly","modcarflightless"),"num"=seq(1,4,1))
modlist$name<-paste0(modlist$model,modlist$num)
modlist$metric<-str_replace_all(modlist$num, '1', "Chao's S")
modlist$metric<-str_replace_all(modlist$metric, '2', "Richness")
modlist$metric<-str_replace_all(modlist$metric, '3', "Abundance")
modlist$metric<-str_replace_all(modlist$metric, '4', "Biomass")
effects_forestgroupmod<-data.frame()

for(i in c(1:length(modlist$model))) {
    ct<-test(emtrends(get(paste(modlist$name[i])), pairwise ~ ForestType, var = "yyyy_scaled"))
  ef<-data.frame(ct$emtrends)
  ef$response<-modlist$metric[i]
  ef$name<-modlist$name[i]
  ef$level<-row.names(ef)
  effects_forestgroupmod<-smartbind(effects_forestgroupmod,ef)
  
}

effects<-effects_forestgroupmod
effects$ForestType <- str_replace_all(effects$ForestType, 'EC', 'Evergreen\nconiferous')
effects$ForestType <- str_replace_all(effects$ForestType, 'DB', 'Deciduous\nbroadleaf')
effects$ForestType <- str_replace_all(effects$ForestType, 'BC', 'Broadleaf\nconiferous\nmixed')
effects$ForestType <- str_replace_all(effects$ForestType, 'EB', 'Evergreen\nbroadleaf')
effects$ForestType<-factor(effects$ForestType,levels=c("Evergreen\nbroadleaf",
                                                       "Broadleaf\nconiferous\nmixed",
                                                       "Evergreen\nconiferous",
                                                       "Deciduous\nbroadleaf"))

effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$group<-str_replace_all(effects$name, 'modsap', 'Saprophages')
effects$group<-str_replace_all(effects$group, 'modpre', 'Predators')
effects$group<-str_replace_all(effects$group, 'modcarab', 'Carabidae')
effects$group<-str_replace_all(effects$group, 'modstaphy', 'Staphylinidae')
effects$group<-str_replace_all(effects$group, 'modsilphid', 'Silphidae')
effects$group<-str_replace_all(effects$group, 'modgeotrup', 'Geotrupidae')
effects$group<-str_replace_all(effects$group, 'modcarfly', 'Flight-capable Carabidae')
effects$group<-str_replace_all(effects$group, 'modcarflightless', 'Flightless Carabidae')
effects$group<-str_replace(effects$group, "[:digit:]","")

effects$lower<-effects$yyyy_scaled.trend-(1.96*effects$SE)
effects$upper<-effects$yyyy_scaled.trend+(1.96*effects$SE)

effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))

effects$group<-factor(effects$group,levels=c("Silphidae","Geotrupidae","Staphylinidae","Flightless Carabidae",
                                             "Flight-capable Carabidae","Carabidae","Saprophages","Predators"))

effects$lower<-ifelse(effects$lower>=-0.7,effects$lower,-0.7)

p<-ggplot(data=effects,  aes(x=yyyy_scaled.trend,y=group,group=response)) +
    
         geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p.value),height=0,position=position_dodge(0.95))+
         geom_col(aes(fill=response,alpha=p.value),position=position_dodge(0.95),width=0.85)+
         geom_hline(yintercept=c(1.5,2.5,3.5,6.5,7.5),linetype=3,colour="grey",size=0.3)+
            xlab("Estimated marginal means")+
         ylab("")+
          geom_vline(xintercept=0,linetype=2,colour="black",size=0.4)+
         theme(panel.grid.major = element_blank(),
               panel.grid.minor = element_blank(),
               panel.background = element_blank(),
               panel.border=element_blank(),
               axis.line=element_line(),
               axis.title.x = element_text(size=10),
               strip.background =element_blank(),
               panel.spacing = unit(0.5,"lines"),
               text=element_text(colour="black"),
               legend.position="bottom",
               legend.spacing = unit(1,"cm"),
               legend.key = element_blank(),
               legend.text=element_text(size=8),
               axis.text.y=element_text(angle=0, vjust=0.5,colour="black"),
               axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
               legend.justification = "top")+
         scale_fill_viridis_d(option="D")+
         scale_colour_viridis_d()+
         scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.001,0.01,0.05,0.1,1),labels=c("0.001","0.01","0.05","0.1","1"))+
         facet_grid(.~ForestType,space="free",scales="free",labeller=labeller(level = label_wrap_gen(8)))+
         scale_x_continuous(breaks=c(seq(-1.5,1.5, 0.5)))+
        coord_cartesian(xlim=c(-0.7, 0.7),clip="off")+
         labs(colour="",fill="",alpha="P value")+
         guides(size="none",
               fill=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
                colour=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
                alpha=guide_legend(title.position = "top",title.hjust = 0.5,reverse=T))

png(filename = "forests_plot_groups.png", width = 5500, height =2800, units = "px",res = 600)
p
dev.off()

ggsave(filename = "Fig_5.pdf", 
       plot = p, 
       device = "pdf", 
       dpi = 600, 
       width = 173,
       height = 125, 
       units = "mm")

######################plot for apa and ata##################

mod<-lm(ATA~yyyy,data=data)
newdata<-data.frame("yyyy"=seq(2005,2018,length.out = 100))
pred<-data.frame(cbind(newdata,predict(mod,newdata=newdata,se.fit = T,type="response",re.form=NA)))
pred$upper<-pred$fit+pred$se.fit*1.96
pred$lower<-pred$fit-pred$se.fit*1.96

sum<-summary(mod)
slope<-format(sum$coefficients[2,1],digits=3)
sel<-round(sum$coefficients[2,1]-sum$coefficients[2,2],3)
seu<-round(sum$coefficients[2,1]+sum$coefficients[2,2],3)
r2<-sum$r.squared

r2<-bquote(italic(R)^2 == .(format(r2, digits = 3)))
plottext<-paste0("Slope = ",slope," (",sel,", ",seu,")")

data$date_proper<-as.Date(paste(data$day,"/",data$month,"/",data$yyyy,sep=""),"%d/%m/%Y")
data$date_cont<-scales::rescale(as.numeric(data$date_proper),to=c(min(data$yyyy,na.rm=T),max(data$yyyy,na.rm=T)))

p_ATA<-ggplot(data=pred,aes(x=yyyy,y=fit))+
  geom_point(data=data,aes(x=date_cont,y=ATA),alpha=0.1,fill="indianred1",colour="firebrick",size=0.5,shape=21,stroke=1.5)+
  geom_line(colour="red",size=1.5)+
  geom_ribbon(inherit.aes=T,aes(ymin=lower,ymax=upper),fill="orange",alpha=0.2)+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="right",
        legend.key=element_blank(),
        legend.background = element_rect(fill="white"),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black",,size=8),
        axis.text.x=element_text(angle=0, vjust=0,hjust=0.5,colour="black",size=8),
        axis.ticks.x = element_blank(),
        legend.text = element_text(size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "centre")+
  annotate(geom="text",x=2007,y=1,label=r2,size=3)+
  annotate(geom="text",x=2013,y=-0.6,label=plottext,size=3)+
  scale_x_continuous(breaks=seq(2005,2020,3))+
  labs(colour="",fill="",shape="")+
  guides(color = guide_legend(override.aes = list(size=1)),fill = guide_legend(override.aes = list(alpha=1)))+
  xlab("Year")+
  ylab("Annual temperature\nanomaly (C)")

mod<-lm(APA~yyyy,data=data)
newdata<-data.frame("yyyy"=seq(2005,2018,length.out = 100))
pred<-data.frame(cbind(newdata,predict(mod,newdata=newdata,se.fit = T,type="response",re.form=NA)))
pred$upper<-pred$fit+pred$se.fit*1.96
pred$lower<-pred$fit-pred$se.fit*1.96

sum<-summary(mod)
slope<-format(sum$coefficients[2,1],digits=3)
sel<-round(sum$coefficients[2,1]-sum$coefficients[2,2],3)
seu<-round(sum$coefficients[2,1]+sum$coefficients[2,2],3)
r2<-sum$r.squared

r2<-bquote(italic(R)^2 == .(format(r2, digits = 3)))
plottext<-paste0("Slope = ",slope," (",sel,", ",seu,")")

data$date_proper<-as.Date(paste(data$day,"/",data$month,"/",data$yyyy,sep=""),"%d/%m/%Y")
data$date_cont<-scales::rescale(as.numeric(data$date_proper),to=c(min(data$yyyy,na.rm=T),max(data$yyyy,na.rm=T)))

p_APA<-ggplot(data=pred,aes(x=yyyy,y=fit))+
  geom_point(data=data,aes(x=date_cont,y=APA),alpha=0.1,fill="lightskyblue",colour="deepskyblue",size=0.5,shape=21,stroke=1.5)+
  geom_line(colour="blue",size=1.5)+
  geom_ribbon(inherit.aes=T,aes(ymin=lower,ymax=upper),fill="skyblue",alpha=0.2)+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="right",
        legend.key=element_blank(),
        legend.background = element_rect(fill="white"),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black",,size=8),
        axis.text.x=element_text(angle=0, vjust=0,hjust=0.5,colour="black",size=8),
        axis.ticks.x = element_blank(),
        legend.text = element_text(size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "centre")+
  annotate(geom="text",x=2007,y=100,label=r2,size=3)+
  annotate(geom="text",x=2012,y=-70,label=plottext,size=3)+
  scale_x_continuous(breaks=seq(2005,2020,3))+
  labs(colour="",fill="",shape="")+
  guides(color = guide_legend(override.aes = list(size=1)),fill = guide_legend(override.aes = list(alpha=1)))+
  xlab("Year")+
  ylab("Annual precipitation\nanomaly (mm)")

clim_trends_plot<-ggarrange(p_ATA,p_APA,ncol=1,labels=c("A.","B."),vjust=c(1.5))

png(filename = "climtrendsplot.png", width = 3000, height =4700, units = "px",res = 600)
clim_trends_plot
dev.off()

###########################################
###########testing for ATA and APA
##############################################
##Testing the ATA effect

mod_ata1<-glmmTMB(chaoS~
                    ForestType*ATA_scaled+
                    urban_factor*ATA_scaled+
                    farmland.mean_1k_scaled*ATA_scaled+
                     Deer_veg_impact*ATA_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod_ata2<-glmmTMB(richness~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                        Deer_veg_impact*ATA_scaled+
                       offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod_ata3<-glmmTMB(abundance~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                             Deer_veg_impact*ATA_scaled+
                       offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod_ata4<-glmmTMB(biomass_log~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                              Deer_veg_impact*ATA_scaled+
                       offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#biomass

effects_atamods<-data.frame()

for(i in c(1:4)) {
  effects<-data.frame(summary(get(paste0("mod_ata",i)))$coef$cond)
  colnames(effects)[length(colnames(effects))]<-"p_value"
  effects$response<-as.character(formula(get(paste0("mod_ata",i)),fixed.only=TRUE,component="cond"))[2]
  effects$dist<-summary(get(paste0("mod_ata",i)))$family
  effects$level<-row.names(effects)
  effects_atamods<-smartbind(effects_atamods,effects)
  }

##plotting

effects<-effects_atamods

effects$lower<-(effects$Estimate-effects$Std..Error*1.96)
effects$upper<-(effects$Estimate+effects$Std..Error*1.96)
effects$group<-revalue(effects$response, c("abundance"="Abundance",
                                           "richness"="Richness",
                                           "biomass_log"="Biomass",
                                           "chaoS"= "Chao's S"))
effects$level <- str_replace_all(effects$level, 'ForestType', '')
effects$level <- str_replace_all(effects$level, 'urban_factorurban', 'Urban')
effects$level <- str_replace_all(effects$level, 'farmland.mean_1k_scaled', 'Farmland')
effects$level <- str_replace_all(effects$level, 'MATave_scaled', "MAT")
effects$level <- str_replace_all(effects$level, 'Deer_presence1', 'Deer presence')
effects$level <- str_replace_all(effects$level, 'Deer_veg_impact1', 'Deer impacts')
effects$level <- str_replace_all(effects$level, 'MAT:ATA', 'ATA:MAT')
effects$level <- str_replace_all(effects$level, 'BC:ATA', 'ATA:BC')
effects$level <- str_replace_all(effects$level, 'EC:ATA', 'ATA:EC')
effects$level <- str_replace_all(effects$level, 'DB:ATA', 'ATA:DB')
effects$level <- str_replace_all(effects$level, 'Deer impacts:ATA', 'ATA:Deer impacts')
effects$level <- str_replace_all(effects$level, 'Deer presence:ATA', 'ATA:Deer presence')
effects$level <- str_replace_all(effects$level, 'Urban:ATA', 'ATA:Urban')
effects$level <- str_replace_all(effects$level, 'EC', 'Evergreen coniferous')
effects$level <- str_replace_all(effects$level, 'DB', 'Deciduous broadleaf')
effects$level <- str_replace_all(effects$level, 'BC', 'Broadleaf coniferous mixed')
effects$level <- str_replace_all(effects$level, 'MAT', 'Mean annual temperature')
effects$level <- str_replace_all(effects$level, '_scaled', '')

effects$int<-"Fixed\neffects"
effects$int[which(str_detect(effects$level,":"))]<-"Interactive\neffects"

effects$group<-factor(effects$group,levels=c("Richness","Chao's S","Abundance","Biomass"))

effects$level<-fct_rev(factor(effects$level,levels=c("ATA","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "ATA:Mean annual temperature","ATA:Evergreen coniferous","ATA:Deciduous broadleaf","ATA:Broadleaf coniferous mixed","ATA:Urban","ATA:Farmland",
                                                     "ATA:Deer impacts")))

effects_sub<-subset(effects,level!="(Intercept)")

effects_sub$p_value<-ifelse(effects_sub$p_value<0.00001,0.00001,effects_sub$p_value)

effects_sub$group<-fct_rev(factor(effects_sub$group,levels=c("Richness","Chao's S","Abundance","Biomass")))
subd<-levels(factor(effects_sub$int))

for( i in c(1,2)) {
  
  assign(paste0("plot", i),ggplot(data=subset(effects_sub, int==subd[i]),  aes(x=Estimate,y=group)) +
           geom_vline(xintercept=0,linetype=2,colour="black")+
           geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),position=position_dodge(0.8),height=0)+
           geom_point(aes(group=response,shape=response),fill="white", col="white",position=position_dodge(0.8),size=3)+
           geom_point(aes(fill=response,group=response,alpha=p_value,shape=response),col="transparent",position=position_dodge(0.8),size=3)+
           geom_vline(xintercept=0,linetype=2,colour="black")+
           xlab("Estimates")+
           ylab("")+
           theme(panel.grid.major = element_blank(),
                 panel.grid.minor = element_blank(),
                 panel.background = element_blank(),
                 panel.border=element_blank(),
                 axis.line=element_line(),
                 strip.background =element_blank(),
                 panel.spacing = unit(0.5,"lines"),
                 strip.text = element_text(size=7),
                 text=element_text(size=12,colour="black"),
                 legend.position="bottom",
                 legend.key = element_blank(),
                 legend.text=element_text(size=6),
                 axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
                 axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
                 legend.justification = "top")+
           scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
           scale_fill_viridis_d()+
           scale_colour_viridis_d()+
           scale_shape_manual(values=c(21,23,24,25))+
           facet_grid(int~level,scales="free",labeller=labeller(level = label_wrap_gen(20)))+
         labs(colour="Metric",fill="Metric",size="P value",alpha="P value",shape="Metric"))
 
 }


effects_plot_time_ata<-ggarrange(plot1,plot2,labels = c("A.","B."), ncol=1,common.legend = TRUE,legend="bottom")

png(filename = "effects_mod_ATA.png", width = 6000, height =2000, units = "px",res = 600)
effects_plot_time_ata
dev.off()

###other effect sizes

effects_other<-subset(effects_sub,int=="Interactive\neffects")
effects_other<-subset(effects_other,level!="ATA:Broadleaf coniferous mixed")
effects_other<-subset(effects_other,level!="ATA:Evergreen coniferous")
effects_other<-subset(effects_other,level!="ATA:Deciduous broadleaf")
effects_other$level<-factor(effects_other$level)

effects_other$group<-fct_rev(factor(effects_other$group,levels=c("Richness","Chao's S","Abundance","Biomass")))

effects_other_ATA_emtrends<-ggplot(data=effects_other,  aes(x=Estimate,y=group)) +
  geom_col(aes(alpha=p_value,fill=group),position=position_dodge(0.6),size=1)+
  geom_errorbarh(aes(xmin=lower,xmax=upper,alpha=p_value,colour=group),height=0)+
  geom_vline(xintercept=0,linetype=2,colour="black")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="right",
        legend.key = element_blank(),
        legend.box.spacing = unit(0, "lines"),
        legend.text=element_text(size=8),
        panel.spacing.x=unit(0.5, "lines"),
        axis.title.x = element_text(),
        plot.title = element_text(hjust=0.5),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black"),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "top")+
  facet_wrap(.~level,ncol=3,labeller=labeller(ForestType = label_wrap_gen(5)))+
  scale_color_viridis_d()+
  scale_fill_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  scale_x_continuous(breaks=c(seq(-0.2,0.4, 0.2)))+
  labs(fill="Metric",col="Metric",alpha="P value")
effects_other_ATA_emtrends


##marginal means of forest plots for ATA

ct<-test(emtrends(mod_ata1, pairwise ~ ForestType, var = "ATA_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Chao's S"
ForContATA<-ct

ct<-test(emtrends(mod_ata2, pairwise ~ ForestType, var = "ATA_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Richness"
ForContATA<-rbind(ForContATA,ct)

ct<-test(emtrends(mod_ata3, pairwise ~ ForestType, var = "ATA_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Abundance"
ForContATA<-rbind(ForContATA,ct)

ct<-test(emtrends(mod_ata4, pairwise ~ ForestType, var = "ATA_scaled"))
ct<-data.frame(ct$contrasts)
ct$response<-"Biomass"
ForContATA<-rbind(ForContATA,ct)

######effect sizes#####
ct<-test(emtrends(mod_ata1, pairwise ~ ForestType, var = "ATA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Chao's S"
ForeffATA<-ef

ct<-test(emtrends(mod_ata2, pairwise ~ ForestType, var = "ATA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Richness"
ForeffATA<-rbind(ForeffATA,ef)

ct<-test(emtrends(mod_ata2, pairwise ~ ForestType, var = "ATA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Abundance"
ForeffATA<-rbind(ForeffATA,ef)

ct<-test(emtrends(mod_ata4, pairwise ~ ForestType, var = "ATA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Biomass"
ForeffATA<-rbind(ForeffATA,ef)


effects<-ForeffATA
effects$ForestType <- str_replace_all(effects$ForestType, 'EC', 'ATA:Evergreen coniferous')
effects$ForestType <- str_replace_all(effects$ForestType, 'DB', 'ATA:Deciduous broadleaf')
effects$ForestType <- str_replace_all(effects$ForestType, 'BC', 'ATA:Broadleaf coniferous mixed')
effects$ForestType <- str_replace_all(effects$ForestType, 'EB', 'ATA:Evergreen broadleaf')
effects$ForestType<-factor(effects$ForestType,levels=c("ATA:Evergreen broadleaf",
                                                       "ATA:Broadleaf coniferous mixed",
                                                       "ATA:Evergreen coniferous",
                                                       "ATA:Deciduous broadleaf"))
effects$lower<-(effects$ATA_scaled.trend-effects$SE*1.96)
effects$upper<-(effects$ATA_scaled.trend+effects$SE*1.96)
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$group<-effects$response
effects$p_value<-effects$p.value

effects_forest_ATA_emtrends<-ggplot(data=effects,  aes(x=ATA_scaled.trend,y=response)) +
  geom_col(aes(alpha=p_value,fill=response),position=position_dodge(0.6),size=1)+
  geom_errorbarh(aes(xmin=lower,xmax=upper,alpha=p_value,colour=response),height=0)+
  geom_vline(xintercept=0,linetype=2,colour="black")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.spacing.y = unit(0,"lines"),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="right",
        legend.key = element_blank(),
        legend.box.spacing = unit(0, "lines"),
        legend.text=element_text(size=8),
        panel.spacing.x=unit(0.5, "lines"),
        axis.title.x = element_text(),
        plot.title = element_text(hjust=0.5),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black"),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "top")+
  facet_wrap(.~ForestType,ncol=2,labeller=labeller(ForestType = label_wrap_gen(5)))+
  scale_color_viridis_d()+
  scale_fill_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  scale_x_continuous(breaks=c(seq(-0.2,0.4, 0.2)))+
  labs(fill="Metric",col="Metric",alpha="P value")
effects_forest_ATA_emtrends

##################
#####APA#######
#################

mod_apa1<-glmmTMB(chaoS~
                    ForestType*APA_scaled+
                    urban_factor*APA_scaled+
                    farmland.mean_1k_scaled*APA_scaled+
                    Deer_veg_impact*APA_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod_apa2<-glmmTMB(richness~
                    ForestType*APA_scaled+
                    urban_factor*APA_scaled+
                    farmland.mean_1k_scaled*APA_scaled+
                    Deer_veg_impact*APA_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod_apa3<-glmmTMB(abundance~
                    ForestType*APA_scaled+
                    urban_factor*APA_scaled+
                    farmland.mean_1k_scaled*APA_scaled+
                    Deer_veg_impact*APA_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

mod_apa4<-glmmTMB(biomass_log~
                    ForestType*APA_scaled+
                    urban_factor*APA_scaled+
                    farmland.mean_1k_scaled*APA_scaled+
                    Deer_veg_impact*APA_scaled+
                    offset(days)+
                    (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                  data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

effects_apamods<-data.frame()

for(i in c(1:4)) {
  effects<-data.frame(summary(get(paste0("mod_apa",i)))$coef$cond)
  colnames(effects)[length(colnames(effects))]<-"p_value"
  effects$response<-as.character(formula(get(paste0("mod_apa",i)),fixed.only=TRUE,component="cond"))[2]
  effects$dist<-summary(get(paste0("mod_apa",i)))$family
  effects$level<-row.names(effects)
  effects_apamods<-smartbind(effects_apamods,effects)
 }

##plotting

effects<-effects_apamods
effects$lower<-(effects$Estimate-effects$Std..Error*1.96)
effects$upper<-(effects$Estimate+effects$Std..Error*1.96)
effects$group<-revalue(effects$response, c("abundance"="Abundance",
                                           "richness"="Richness",
                                           "biomass_log"="Biomass",
                                           "chaoS"= "Chao's S"))

effects$level <- str_replace_all(effects$level, 'ForestType', '')
effects$level <- str_replace_all(effects$level, 'urban_factorurban', 'Urban')
effects$level <- str_replace_all(effects$level, 'farmland.mean_1k_scaled', 'Farmland')
effects$level <- str_replace_all(effects$level, 'MATave_scaled', "MAT")
effects$level <- str_replace_all(effects$level, 'Deer_presence1', 'Deer presence')
effects$level <- str_replace_all(effects$level, 'Deer_veg_impact1', 'Deer impacts')
effects$level <- str_replace_all(effects$level, 'MAT:APA', 'APA:MAT')
effects$level <- str_replace_all(effects$level, 'BC:APA', 'APA:BC')
effects$level <- str_replace_all(effects$level, 'EC:APA', 'APA:EC')
effects$level <- str_replace_all(effects$level, 'DB:APA', 'APA:DB')
effects$level <- str_replace_all(effects$level, 'Deer impacts:APA', 'APA:Deer impacts')
effects$level <- str_replace_all(effects$level, 'Deer presence:APA', 'APA:Deer presence')
effects$level <- str_replace_all(effects$level, 'Urban:APA', 'APA:Urban')
effects$level <- str_replace_all(effects$level, 'EC', 'Evergreen coniferous')
effects$level <- str_replace_all(effects$level, 'DB', 'Deciduous broadleaf')
effects$level <- str_replace_all(effects$level, 'BC', 'Broadleaf coniferous mixed')
effects$level <- str_replace_all(effects$level, 'MAT', 'Mean annual precipitation')
effects$level <- str_replace_all(effects$level, '_scaled', '')
effects$level

effects$int<-"Fixed\neffects"
effects$int[which(str_detect(effects$level,":"))]<-"Interactive\neffects"

effects$group<-fct_rev(factor(effects$group,levels=c("Richness","Chao's S","Abundance","Biomass")))

effects$level<-fct_rev(factor(effects$level,levels=c("APA","Mean annual precipitation","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "APA:Mean annual precipitation","APA:Evergreen coniferous","APA:Deciduous broadleaf","APA:Broadleaf coniferous mixed","APA:Urban","APA:Farmland",
                                                     "APA:Deer impacts")))

effects_sub<-subset(effects,level!="(Intercept)")
effects_sub$p_value<-ifelse(effects_sub$p_value<0.00001,0.00001,effects_sub$p_value)
effects$group<-fct_rev(factor(effects$group,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects_sub$group<-fct_rev(factor(effects_sub$group,levels=c("Richness","Chao's S","Abundance","Biomass")))

subd<-levels(factor(effects_sub$int))
for( i in c(1,2)) {
    assign(paste0("plot", i),ggplot(data=subset(effects_sub, int==subd[i]),  aes(x=Estimate,y=group)) +
           geom_vline(xintercept=0,linetype=2,colour="black")+
           geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),position=position_dodge(0.8),height=0)+
           geom_point(aes(group=response,shape=response),fill="white", col="white",position=position_dodge(0.8),size=3)+
           geom_point(aes(fill=response,group=response,alpha=p_value,shape=response),col="transparent",position=position_dodge(0.8),size=3)+
           geom_vline(xintercept=0,linetype=2,colour="black")+
          xlab("Estimates")+
           ylab("")+
           theme(panel.grid.major = element_blank(),
                 panel.grid.minor = element_blank(),
                 panel.background = element_blank(),
                 panel.border=element_blank(),
                 axis.line=element_line(),
                 strip.background =element_blank(),
                 panel.spacing = unit(0.5,"lines"),
                 strip.text = element_text(size=7),
                 text=element_text(size=12,colour="black"),
                 legend.position="bottom",
                 legend.key = element_blank(),
                 legend.text=element_text(size=6),
                 axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
                 axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
                                 legend.justification = "top")+
           scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
           scale_fill_viridis_d()+
           scale_colour_viridis_d()+
           scale_shape_manual(values=c(21,23,24,25))+
           facet_grid(int~level,scales="free",labeller=labeller(level = label_wrap_gen(20)))+
           labs(colour="Metric",fill="Metric",size="P value",alpha="P value",shape="Metric"))
  
}


effects_plot_time_apa<-ggarrange(plot1,plot2,labels = c("A.","B."), ncol=1,common.legend = TRUE,legend="bottom")

png(filename = "effects_mod_APA.png", width = 6000, height =2000, units = "px",res = 600)
effects_plot_time_apa
dev.off()


###other effect sizes

effects_other<-subset(effects_sub,int=="Interactive\neffects")
effects_other<-subset(effects_other,level!="APA:Broadleaf coniferous mixed")
effects_other<-subset(effects_other,level!="APA:Evergreen coniferous")
effects_other<-subset(effects_other,level!="APA:Deciduous broadleaf")
effects_other$level<-factor(effects_other$level)

effects_other$group<-fct_rev(factor(effects_other$group,levels=c("Richness","Chao's S","Abundance","Biomass")))

effects_other_APA_emtrends<-ggplot(data=effects_other,  aes(x=Estimate,y=group)) +
  geom_col(aes(alpha=p_value,fill=group),position=position_dodge(0.6),size=1)+
  geom_errorbarh(aes(xmin=lower,xmax=upper,alpha=p_value,colour=group),height=0)+
  geom_vline(xintercept=0,linetype=2,colour="black")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="right",
        legend.key = element_blank(),
        legend.box.spacing = unit(0, "lines"),
        legend.text=element_text(size=8),
        panel.spacing.x=unit(0.5, "lines"),
        axis.title.x = element_text(),
        plot.title = element_text(hjust=0.5),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black"),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "top")+
  facet_wrap(.~level,ncol=3,labeller=labeller(ForestType = label_wrap_gen(5)))+
  scale_color_viridis_d()+
  scale_fill_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  scale_x_continuous(breaks=c(seq(-0.2,0.4, 0.2)))+
  labs(fill="Metric",col="Metric",alpha="P value")

######emeans#####
ct<-test(emtrends(mod_apa1, pairwise ~ ForestType, var = "APA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Chao's S"
ForeffAPA<-ef

ct<-test(emtrends(mod_apa2, pairwise ~ ForestType, var = "APA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Richness"
ForeffAPA<-rbind(ForeffAPA,ef)

ct<-test(emtrends(mod_apa2, pairwise ~ ForestType, var = "APA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Abundance"
ForeffAPA<-rbind(ForeffAPA,ef)

ct<-test(emtrends(mod_apa4, pairwise ~ ForestType, var = "APA_scaled"))
ef<-data.frame(ct$emtrends)
ef$response<-"Biomass"
ForeffAPA<-rbind(ForeffAPA,ef)

effects<-ForeffAPA
effects$ForestType <- str_replace_all(effects$ForestType, 'EC', 'APA:Evergreen coniferous')
effects$ForestType <- str_replace_all(effects$ForestType, 'DB', 'APA:Deciduous broadleaf')
effects$ForestType <- str_replace_all(effects$ForestType, 'BC', 'APA:Broadleaf coniferous mixed')
effects$ForestType <- str_replace_all(effects$ForestType, 'EB', 'APA:Evergreen broadleaf')
effects$ForestType<-factor(effects$ForestType,levels=c("APA:Evergreen broadleaf",
                                                       "APA:Broadleaf coniferous mixed",
                                                       "APA:Evergreen coniferous",
                                                       "APA:Deciduous broadleaf"))
effects$lower<-(effects$APA_scaled.trend-effects$SE*1.96)
effects$upper<-(effects$APA_scaled.trend+effects$SE*1.96)
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))

effects_forest_APA_emtrends<-ggplot(data=effects,  aes(x=APA_scaled.trend,y=response)) +
  geom_col(aes(alpha=p.value,fill=response),position=position_dodge(0.6),size=1)+
  geom_errorbarh(aes(xmin=lower,xmax=upper,alpha=p.value,colour=response),height=0)+
  geom_vline(xintercept=0,linetype=2,colour="black")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        panel.spacing.y = unit(0,"lines"),
        axis.line=element_line(),
        strip.background =element_blank(),
        text=element_text(colour="black"),
        legend.position="right",
        legend.key = element_blank(),
        legend.box.spacing = unit(0, "lines"),
        legend.text=element_text(size=8),
        panel.spacing.x=unit(0.5, "lines"),
        axis.title.x = element_text(),
        plot.title = element_text(hjust=0.5),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black"),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
        panel.spacing = unit(2, "lines"),
        legend.justification = "top")+
  facet_wrap(.~ForestType,ncol=2,labeller=labeller(ForestType = label_wrap_gen(5)))+
  scale_color_viridis_d()+
  scale_fill_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  scale_x_continuous(breaks=c(seq(-0.2,0.4, 0.2)))+
  labs(fill="Metric",col="Metric",alpha="P value")

############combinginf##############################################

fakedata<-data.frame("P value"=c(0.00001,0.0001,0.001,0.01,0.05,0.1,1),"arse"=c(0.00001,0.0001,0.001,0.01,0.05,0.1,1),dave=c("dave","bob","dave","bob","dave","bob","dave"))
fakedata$ddddd<-as.numeric(as.character(fakedata$arse))

legendplot<-ggplot(data=fakedata,  aes(x=ddddd,y=dave)) +
  geom_col(aes(fill=ddddd))+
  geom_errorbarh(aes(xmin=ddddd,xmax=ddddd,colour=ddddd),height=0,colour="grey")+
  theme_blank()+
  theme(legend.text = element_text(size=6),
        legend.title =element_text(size=8),
        legend.position = "bottom")+
  scale_fill_distiller(palette = "Greys",trans="sqrt",breaks=c(0.0001,0.01,0.05,0.1,0.2,0.5),labels=c("0.0001","0.01","0.05","0.1","0.2", "0.5"))+
  scale_colour_distiller(palette = "Greys",trans="sqrt",breaks=c(0.0001,0.01,0.05,0.1,0.2,0.5),labels=c("0.0001","0.01","0.05","0.1","0.2","0.5"))+
  labs(colour="P value",fill="P value",alpha="P value")+
  guides(size=guide_legend(title.position = "top",title.hjust = 0.5),
          #colour=guide_colorbar(title.position = "top",title.hjust = 0.5),
         fill=guide_colorbar(title.position = "top",title.hjust = 0.5,barwidth = unit(12,"cm"),barheight = unit(0.4,"cm")))

leg<-get_legend(legendplot)

p1<-ggarrange(p_ATA,effects_forest_ATA_emtrends,nrow=1, labels =c("A.","B."), widths=c(1,1.3),legend="none")
p2<-ggarrange(p1,effects_other_ATA_emtrends, nrow=2, labels =c("","C."), heights = c(1.8,0.85),legend="none")
p3<-ggarrange(p_APA,effects_forest_APA_emtrends,nrow=1, labels =c("D.","E."), widths=c(1,1.3),legend="none")
p4<-ggarrange(p3,effects_other_APA_emtrends, nrow=2, labels =c("","F."), heights = c(1.8,0.85),legend="none")
p5<-ggarrange(p2,p4, ncol=1,align="hv")

forest_anoms_plot<-ggarrange(p5,leg,ncol=1,heights=c(10,0.8))

png(filename = "forest_anoms_plot.png", width = 6000, height =6600, units = "px",res = 700)
forest_anoms_plot
dev.off()

ggsave(filename = "Fig_4.pdf", 
       plot = forest_anoms_plot, 
       device = "pdf", 
       dpi = 600, 
       width = 173,
       height = 220, 
       units = "mm")


########################
#######GUILDS ATA#########
######################

#Predators
data$response<-data$`Predators (Chao's S)`
modATApre1<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$`Predators (richness)`
modATApre2<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$`Predators (abundance)`
modATApre3<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Predators (biomass)`+1)
modATApre4<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#Saprophagous
data$response<-data$`Saprophages (Chao's S)`
modATAsap1<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2")#,ziformula = ~1)

data$response<-data$`Saprophages (richness)`
modATAsap2<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="poisson")

data$response<-data$`Saprophages (abundance)`
modATAsap3<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Saprophages (biomass)`+1)
modATAsap4<-glmmTMB(response~
                   ForestType*ATA_scaled+
                   urban_factor*ATA_scaled+
                   farmland.mean_1k_scaled*ATA_scaled+
                   Deer_veg_impact*ATA_scaled+
                   offset(days)+
                   (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                 data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#carab
data$response<-data$`Carabidae (Chao's S)`
modATAcarab1<-glmmTMB(response~
                     ForestType*ATA_scaled+
                     urban_factor*ATA_scaled+
                     farmland.mean_1k_scaled*ATA_scaled+
                     Deer_veg_impact*ATA_scaled+
                     offset(days)+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$Carabidae_richness
modATAcarab2<-glmmTMB(response~
                     ForestType*ATA_scaled+
                     urban_factor*ATA_scaled+
                     farmland.mean_1k_scaled*ATA_scaled+
                     Deer_veg_impact*ATA_scaled+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$Carabidae_abundance
modATAcarab3<-glmmTMB(response~
                     ForestType*ATA_scaled+
                     urban_factor*ATA_scaled+
                     farmland.mean_1k_scaled*ATA_scaled+
                     Deer_veg_impact*ATA_scaled+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Carabidae (biomass)`+1)
modATAcarab4<-glmmTMB(response~
                     ForestType*ATA_scaled+
                     urban_factor*ATA_scaled+
                     farmland.mean_1k_scaled*ATA_scaled+
                     Deer_veg_impact*ATA_scaled+
                     offset(days)+
                     (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                   data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#carab flight capable
data$response<-data$carabids_fly_chaos
modATAcarabfly1<-glmmTMB(response~
                        ForestType*ATA_scaled+
                        urban_factor*ATA_scaled+
                        farmland.mean_1k_scaled*ATA_scaled+
                        Deer_veg_impact*ATA_scaled+
                        offset(days)+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$carabidfly_richness
modATAcarabfly2<-glmmTMB(response~
                        ForestType*ATA_scaled+
                        urban_factor*ATA_scaled+
                        farmland.mean_1k_scaled*ATA_scaled+
                        Deer_veg_impact*ATA_scaled+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="poisson",REML=F)

data$response<-data$carabidfly_abundance
modATAcarabfly3<-glmmTMB(response~
                        ForestType*ATA_scaled+
                        urban_factor*ATA_scaled+
                        farmland.mean_1k_scaled*ATA_scaled+
                        Deer_veg_impact*ATA_scaled+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$carabidfly_mass+1)
modATAcarabfly4<-glmmTMB(response~
                        ForestType*ATA_scaled+
                        urban_factor*ATA_scaled+
                        farmland.mean_1k_scaled*ATA_scaled+
                        Deer_veg_impact*ATA_scaled+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)


#carab flight capable
data$response<-data$carabids_flightless_chaos
modATAcarabflightless1<-glmmTMB(response~
                           ForestType*ATA_scaled+
                           urban_factor*ATA_scaled+
                           farmland.mean_1k_scaled*ATA_scaled+
                           Deer_veg_impact*ATA_scaled+
                           offset(days)+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="nbinom2")


data$response<-data$carabidflightless_richness
modATAcarabflightless2<-glmmTMB(response~
                           ForestType*ATA_scaled+
                           urban_factor*ATA_scaled+
                           farmland.mean_1k_scaled*ATA_scaled+
                           Deer_veg_impact*ATA_scaled+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$carabidflightless_abundance
modATAcarabflightless3<-glmmTMB(response~
                           ForestType*ATA_scaled+
                           urban_factor*ATA_scaled+
                           farmland.mean_1k_scaled*ATA_scaled+
                           Deer_veg_impact*ATA_scaled+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$carabidflightless_mass+1)
modATAcarabflightless4<-glmmTMB(response~
                           ForestType*ATA_scaled+
                           urban_factor*ATA_scaled+
                           farmland.mean_1k_scaled*ATA_scaled+
                           Deer_veg_impact*ATA_scaled+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###staphylindae
data$response<-data$`Staphylinidae (Chao's S)`
modATAstaphy1<-glmmTMB(response~
                      ForestType*ATA_scaled+
                      urban_factor*ATA_scaled+
                      farmland.mean_1k_scaled*ATA_scaled+
                      Deer_veg_impact*ATA_scaled+
                      offset(days)+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,control=glmmTMBControl(optimizer=optim,
                                                                                                         optArgs=list(method="BFGS")))

data$response<-data$Staphylinidae_richness
modATAstaphy2<-glmmTMB(response~
                      ForestType*ATA_scaled+
                      urban_factor*ATA_scaled+
                      farmland.mean_1k_scaled*ATA_scaled+
                      Deer_veg_impact*ATA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F,control=glmmTMBControl(optimizer=optim,
                                                                                                                optArgs=list(method="BFGS")))

data$response<-data$Staphylinidae_abundance
modATAstaphy3<-glmmTMB(response~
                      ForestType*ATA_scaled+
                      urban_factor*ATA_scaled+
                      farmland.mean_1k_scaled*ATA_scaled+
                      Deer_veg_impact*ATA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Staphylinidae (biomass)`+1)
modATAstaphy4<-glmmTMB(response~
                      ForestType*ATA_scaled+
                      urban_factor*ATA_scaled+
                      farmland.mean_1k_scaled*ATA_scaled+
                      Deer_veg_impact*ATA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###silphid
data$response<-data$`Silphidae (Chao's S)`
modATAsilphid1<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="nbinom2",control=glmmTMBControl(optimizer=optim,
                                                                                                          optArgs=list(method="BFGS")))

data$response<-data$Silphidae_richness
modATAsilphid2<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="poisson",ziformula = ~1,control=glmmTMBControl(optimizer=optim,
                                                                                                          optArgs=list(method="BFGS")))

data$response<-data$Silphidae_abundance
modATAsilphid3<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Silphidae (biomass)`+1)
modATAsilphid4<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###GEOTRUPIDAE
data$response<-data$`Geotrupidae (Chao's S)`
modATAgeotrup1<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       offset(days)+
                       (1|Site_Name) + (1|season),
                     data=data,na.action="na.fail",family="poisson",ziformula = ~1)
data$response<-data$Geotrupidae_richness
modATAgeotrup2<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="poisson", ziformula = ~1)

data$response<-data$Geotrupidae_abundance
modATAgeotrup3<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Geotrupidae (biomass)`+1)
modATAgeotrup4<-glmmTMB(response~
                       ForestType*ATA_scaled+
                       urban_factor*ATA_scaled+
                       farmland.mean_1k_scaled*ATA_scaled+
                       Deer_veg_impact*ATA_scaled+
                       offset(days)+
                       (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                     data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

####Group modATAs

modATAlist=expand.grid("model"=c("modATApre","modATAsap","modATAcarab","modATAcarabfly", "modATAcarabflightless","modATAstaphy","modATAsilphid","modATAgeotrup"),"num"=seq(1,4,1))
modATAlist$name<-paste0(modATAlist$model,modATAlist$num)
modATAlist$metric<-str_replace_all(modATAlist$num, '1', "Chao's S")
modATAlist$metric<-str_replace_all(modATAlist$metric, '2', "Richness")
modATAlist$metric<-str_replace_all(modATAlist$metric, '3', "Abundance")
modATAlist$metric<-str_replace_all(modATAlist$metric, '4', "Biomass")

effects_groupmodATAs<-data.frame()

for(i in c(1:length(modATAlist$model))) {
  effects<-data.frame(summary(get(paste(modATAlist$name[i])))$coef$cond)
  colnames(effects)[length(colnames(effects))]<-"p_value"
  effects$response<-modATAlist$metric[i]
  effects$modATA<-modATAlist$name[i]
  effects$level<-row.names(effects)
  effects_groupmodATAs<-smartbind(effects_groupmodATAs,effects)
  
}


#####plotting

effects<-effects_groupmodATAs

effects$lower<-(effects$Estimate-effects$Std..Error*1.96)
effects$upper<-(effects$Estimate+effects$Std..Error*1.96)

effects$level <- str_replace_all(effects$level, 'ATA_scaled', 'ATA')
effects$level <- str_replace_all(effects$level, 'ForestType', '')
effects$level <- str_replace_all(effects$level, 'urban_factorurban', 'Urban')
effects$level <- str_replace_all(effects$level, 'farmland.mean_1k_scaled', 'Farmland')
effects$level <- str_replace_all(effects$level, 'MATave_scaled', "MAT")
effects$level <- str_replace_all(effects$level, 'Deer_presence1', 'Deer presence')
effects$level <- str_replace_all(effects$level, 'Deer_veg_impact1', 'Deer impacts')
effects$level <- str_replace_all(effects$level, 'MAT:ATA', 'ATA:MAT')
effects$level <- str_replace_all(effects$level, 'BC:ATA', 'ATA:BC')
effects$level <- str_replace_all(effects$level, 'EC:ATA', 'ATA:EC')
effects$level <- str_replace_all(effects$level, 'DB:ATA', 'ATA:DB')
effects$level <- str_replace_all(effects$level, 'Deer impacts:ATA', 'ATA:Deer impacts')
effects$level <- str_replace_all(effects$level, 'Deer presence:ATA', 'ATA:Deer presence')
effects$level <- str_replace_all(effects$level, 'Urban:ATA', 'ATA:Urban')
effects$level <- str_replace_all(effects$level, 'EC', 'Evergreen coniferous')
effects$level <- str_replace_all(effects$level, 'DB', 'Deciduous broadleaf')
effects$level <- str_replace_all(effects$level, 'BC', 'Broadleaf coniferous mixed')
effects$level <- str_replace_all(effects$level, 'MAT', 'Mean annual temperature')
effects$group<-str_replace_all(effects$modATA, 'modATAsap', 'Saprophages')
effects$group<-str_replace_all(effects$group, 'modATApre', 'Predators')
effects$group<-str_replace_all(effects$group, 'modATAcarabfly', 'Flight-capable Carabidae')
effects$group<-str_replace_all(effects$group, 'modATAcarabflightless', 'Flightless Carabidae')
effects$group<-str_replace_all(effects$group, 'modATAcarab', 'Carabidae')
effects$group<-str_replace_all(effects$group, 'modATAstaphy', 'Staphylinidae')
effects$group<-str_replace_all(effects$group, 'modATAsilphid', 'Silphidae')
effects$group<-str_replace_all(effects$group, 'modATAgeotrup', 'Geotrupidae')

effects$group<-str_replace(effects$group, "[:digit:]","")
effects$int<-"Fixed\neffects"
effects$int[which(str_detect(effects$level,":"))]<-"Interactive\neffects"
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$level<-fct_rev(factor(effects$level,levels=c("ATA","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "ATA:Mean annual temperature","ATA:Evergreen coniferous","ATA:Deciduous broadleaf","ATA:Broadleaf coniferous mixed","ATA:Urban","ATA:Farmland",
                                                     "ATA:Deer impacts")))
effects$group<-factor(factor(effects$group,levels=c("Silphidae","Geotrupidae","Staphylinidae",
                                                    "Flightless Carabidae","Flight-capable Carabidae","Carabidae","Saprophages","Predators")))
effects_sub<-subset(effects,level!="(Intercept)")
effects_sub$p_value<-ifelse(effects_sub$p_value<0.00001,0.00001,effects_sub$p_value)
subd<-levels(factor(effects_sub$int))

for( i in c(1,2)) {
  
  assign(paste0("plot", i),ggplot(data=subset(effects_sub, int==subd[i]),  aes(x=Estimate,y=group)) +
           geom_vline(xintercept=0,linetype=2,colour="black")+
           geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),position=position_dodge(0.8),height=0)+
           geom_point(aes(group=response,shape=response),fill="white", col="white",position=position_dodge(0.8),size=2)+
           geom_point(aes(fill=response,group=response,alpha=p_value,shape=response),col="transparent",position=position_dodge(0.8),size=2)+
           geom_vline(xintercept=0,linetype=2,colour="black")+
           xlab("Estimates")+
           ylab("")+
           theme(panel.grid.major = element_blank(),
                 panel.grid.minor = element_blank(),
                 panel.background = element_blank(),
                 panel.border=element_blank(),
                 axis.line=element_line(),
                 strip.background =element_blank(),
                 panel.spacing = unit(0.5,"lines"),
                 strip.text = element_text(size=7),
                             text=element_text(size=12,colour="black"),
                 legend.position="bottom",
                 legend.key = element_blank(),
                 legend.text=element_text(size=6),
                 axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
                 axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
                 scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
           scale_fill_viridis_d()+
           scale_colour_viridis_d()+
           scale_shape_manual(values=c(21,23,24,25))+
           facet_grid(int~level,scales="free",labeller=labeller(level = label_wrap_gen(20)))+
            labs(colour="Metric",fill="Metric",size="P value",alpha="P value",shape="Metric"))
  
  }

effects_plot_groups_ata<-ggarrange(plot1,plot2,labels = c("A.","B."), ncol=1,common.legend = TRUE,legend="bottom")

png(filename = "effects_mod_ATA_groups.png", width = 6000, height =5000, units = "px",res = 600)
effects_plot_groups_ata
dev.off()


#######################################
###########GUILDS APA##################
#######################################


#Predators
data$response<-data$`Predators (Chao's S)`
modAPApre1<-glmmTMB(response~
                        ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$`Predators (richness)`
modAPApre2<-glmmTMB(response~
                      ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$`Predators (abundance)`
modAPApre3<-glmmTMB(response~
                      ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Predators (biomass)`+1)
modAPApre4<-glmmTMB(response~
                      ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#Saprophagous
data$response<-data$`Saprophages (Chao's S)`
modAPAsap1<-glmmTMB(response~
                          ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2")

data$response<-data$`Saprophages (richness)`
modAPAsap2<-glmmTMB(response~
                      ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="poisson")

data$response<-data$`Saprophages (abundance)`
modAPAsap3<-glmmTMB(response~
                      ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Saprophages (biomass)`+1)
modAPAsap4<-glmmTMB(response~
                      ForestType*APA_scaled+
                      urban_factor*APA_scaled+
                      farmland.mean_1k_scaled*APA_scaled+
                      Deer_veg_impact*APA_scaled+
                      offset(days)+
                      (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                    data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#carab
data$response<-data$`Carabidae (Chao's S)`
modAPAcarab1<-glmmTMB(response~
                        ForestType*APA_scaled+
                        urban_factor*APA_scaled+
                        farmland.mean_1k_scaled*APA_scaled+
                        Deer_veg_impact*APA_scaled+
                        offset(days)+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$Carabidae_richness
modAPAcarab2<-glmmTMB(response~
                        ForestType*APA_scaled+
                        urban_factor*APA_scaled+
                        farmland.mean_1k_scaled*APA_scaled+
                        Deer_veg_impact*APA_scaled+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-data$Carabidae_abundance
modAPAcarab3<-glmmTMB(response~
                        ForestType*APA_scaled+
                        urban_factor*APA_scaled+
                        farmland.mean_1k_scaled*APA_scaled+
                        Deer_veg_impact*APA_scaled+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Carabidae (biomass)`+1)
modAPAcarab4<-glmmTMB(response~
                        ForestType*APA_scaled+
                        urban_factor*APA_scaled+
                        farmland.mean_1k_scaled*APA_scaled+
                        Deer_veg_impact*APA_scaled+
                        offset(days)+
                        (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                      data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

#carab flight capable
data$response<-data$carabids_fly_chaos
modAPAcarabfly1<-glmmTMB(response~
                           ForestType*APA_scaled+
                           urban_factor*APA_scaled+
                           farmland.mean_1k_scaled*APA_scaled+
                           Deer_veg_impact*APA_scaled+
                           offset(days)+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="nbinom2",ziformula = ~1)

data$response<-data$carabidfly_richness
modAPAcarabfly2<-glmmTMB(response~
                           ForestType*APA_scaled+
                           urban_factor*APA_scaled+
                           farmland.mean_1k_scaled*APA_scaled+
                           Deer_veg_impact*APA_scaled+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="poisson",REML=F)

data$response<-data$carabidfly_abundance
modAPAcarabfly3<-glmmTMB(response~
                           ForestType*APA_scaled+
                           urban_factor*APA_scaled+
                           farmland.mean_1k_scaled*APA_scaled+
                           Deer_veg_impact*APA_scaled+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$carabidfly_mass+1)
modAPAcarabfly4<-glmmTMB(response~
                           ForestType*APA_scaled+
                           urban_factor*APA_scaled+
                           farmland.mean_1k_scaled*APA_scaled+
                           Deer_veg_impact*APA_scaled+
                           offset(days)+
                           (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                         data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)
#carab flight capable
data$response<-data$carabids_flightless_chaos
modAPAcarabflightless1<-glmmTMB(response~
                                  ForestType*APA_scaled+
                                  urban_factor*APA_scaled+
                                  farmland.mean_1k_scaled*APA_scaled+
                                  Deer_veg_impact*APA_scaled+
                                  offset(days)+
                                  offset(days)+
                                  (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                                data=data,na.action="na.fail",family="nbinom2")

check_zeroinflation(modAPAcarabflightless1)

data$response<-data$carabidflightless_richness
modAPAcarabflightless2<-glmmTMB(response~
                                  ForestType*APA_scaled+
                                  urban_factor*APA_scaled+
                                  farmland.mean_1k_scaled*APA_scaled+
                                  Deer_veg_impact*APA_scaled+
                                  offset(days)+
                                  (1|MAIN_PLOT_ID) + (1|season),
                                data=data,na.action="na.fail",family="nbinom2",control=glmmTMBControl(optimizer=optim,
                                                                                                      optArgs=list(method="BFGS")))

data$response<-data$carabidflightless_abundance
modAPAcarabflightless3<-glmmTMB(response~
                                  ForestType*APA_scaled+
                                  urban_factor*APA_scaled+
                                  farmland.mean_1k_scaled*APA_scaled+
                                  Deer_veg_impact*APA_scaled+
                                  offset(days)+
                                  (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                                data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$carabidflightless_mass+1)
modAPAcarabflightless4<-glmmTMB(response~
                                  ForestType*APA_scaled+
                                  urban_factor*APA_scaled+
                                  farmland.mean_1k_scaled*APA_scaled+
                                  Deer_veg_impact*APA_scaled+
                                  offset(days)+
                                  (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                                data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###staphylindae
data$response<-data$`Staphylinidae (Chao's S)`
modAPAstaphy1<-glmmTMB(response~
                         ForestType*APA_scaled+
                         urban_factor*APA_scaled+
                         farmland.mean_1k_scaled*APA_scaled+
                         Deer_veg_impact*APA_scaled+
                         offset(days)+
                         offset(days)+
                         (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                       data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,control=glmmTMBControl(optimizer=optim,
                                                                                                            optArgs=list(method="BFGS")))

data$response<-data$Staphylinidae_richness
modAPAstaphy2<-glmmTMB(response~
                         ForestType*APA_scaled+
                         urban_factor*APA_scaled+
                         farmland.mean_1k_scaled*APA_scaled+
                         Deer_veg_impact*APA_scaled+
                         offset(days)+
                         (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                       data=data,na.action="na.fail",family="nbinom2",REML=F)

data$response<-data$Staphylinidae_abundance
modAPAstaphy3<-glmmTMB(response~
                         ForestType*APA_scaled+
                         urban_factor*APA_scaled+
                         farmland.mean_1k_scaled*APA_scaled+
                         Deer_veg_impact*APA_scaled+
                         offset(days)+
                         (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                       data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Staphylinidae (biomass)`+1)
modAPAstaphy4<-glmmTMB(response~
                         ForestType*APA_scaled+
                         urban_factor*APA_scaled+
                         farmland.mean_1k_scaled*APA_scaled+
                         Deer_veg_impact*APA_scaled+
                         offset(days)+
                         (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                       data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###silphid
data$response<-data$`Silphidae (Chao's S)`
modAPAsilphid1<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,control=glmmTMBControl(optimizer=optim,
                                                                                                             optArgs=list(method="BFGS")))

data$response<-data$Silphidae_richness
modAPAsilphid2<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,control=glmmTMBControl(optimizer=optim,
                                                                                                             optArgs=list(method="BFGS")))

data$response<-data$Silphidae_abundance
modAPAsilphid3<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Silphidae (biomass)`+1)
modAPAsilphid4<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

###GEOTRUPIDAE
data$response<-data$`Geotrupidae (Chao's S)`
modAPAgeotrup1<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="poisson",ziformula = ~1)

check_overdispersion(modAPAgeotrup1)
check_zeroinflation(modAPAgeotrup1)


data$response<-data$Geotrupidae_richness
modAPAgeotrup2<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          (1|Site_Name) + (1|season),
                        data=data,na.action="na.fail",family="poisson",ziformula = ~1)

data$response<-data$Geotrupidae_abundance
modAPAgeotrup3<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="nbinom2",ziformula = ~1,REML=F)

data$response<-log(data$`Geotrupidae (biomass)`+1)
modAPAgeotrup4<-glmmTMB(response~
                          ForestType*APA_scaled+
                          urban_factor*APA_scaled+
                          farmland.mean_1k_scaled*APA_scaled+
                          Deer_veg_impact*APA_scaled+
                          offset(days)+
                          (1|Site_Name/MAIN_PLOT_ID) + (1|season),
                        data=data,na.action="na.fail",family="gaussian",ziformula = ~1,REML=F)

####Group modAPAs

modAPAlist=expand.grid("model"=c("modAPApre","modAPAsap","modAPAcarab","modAPAcarabfly","modAPAcarabflightless","modAPAstaphy","modAPAsilphid","modAPAgeotrup"),"num"=seq(1,4,1))
modAPAlist$name<-paste0(modAPAlist$model,modAPAlist$num)
modAPAlist$metric<-str_replace_all(modAPAlist$num, '1', "Chao's S")
modAPAlist$metric<-str_replace_all(modAPAlist$metric, '2', "Richness")
modAPAlist$metric<-str_replace_all(modAPAlist$metric, '3', "Abundance")
modAPAlist$metric<-str_replace_all(modAPAlist$metric, '4', "Biomass")

effects_groupmodAPAs<-data.frame()

for(i in c(1:length(modAPAlist$model))) {
  
  effects<-data.frame(summary(get(paste(modAPAlist$name[i])))$coef$cond)
  colnames(effects)[length(colnames(effects))]<-"p_value"
  effects$response<-modAPAlist$metric[i]
  effects$modAPA<-modAPAlist$name[i]
  effects$level<-row.names(effects)
  effects_groupmodAPAs<-smartbind(effects_groupmodAPAs,effects)
  
}

#####plotting

effects<-effects_groupmodAPAs
effects$lower<-(effects$Estimate-effects$Std..Error*1.96)
effects$upper<-(effects$Estimate+effects$Std..Error*1.96)

effects$level <- str_replace_all(effects$level, 'APA_scaled', 'APA')
effects$level <- str_replace_all(effects$level, 'ForestType', '')
effects$level <- str_replace_all(effects$level, 'urban_factorurban', 'Urban')
effects$level <- str_replace_all(effects$level, 'farmland.mean_1k_scaled', 'Farmland')
effects$level <- str_replace_all(effects$level, 'MATave_scaled', "MAT")
effects$level <- str_replace_all(effects$level, 'Deer_presence1', 'Deer presence')
effects$level <- str_replace_all(effects$level, 'Deer_veg_impact1', 'Deer impacts')
effects$level <- str_replace_all(effects$level, 'MAT:APA', 'APA:MAT')
effects$level <- str_replace_all(effects$level, 'BC:APA', 'APA:BC')
effects$level <- str_replace_all(effects$level, 'EC:APA', 'APA:EC')
effects$level <- str_replace_all(effects$level, 'DB:APA', 'APA:DB')
effects$level <- str_replace_all(effects$level, 'Deer impacts:APA', 'APA:Deer impacts')
effects$level <- str_replace_all(effects$level, 'Deer presence:APA', 'APA:Deer presence')
effects$level <- str_replace_all(effects$level, 'Urban:APA', 'APA:Urban')
effects$level <- str_replace_all(effects$level, 'EC', 'Evergreen coniferous')
effects$level <- str_replace_all(effects$level, 'DB', 'Deciduous broadleaf')
effects$level <- str_replace_all(effects$level, 'BC', 'Broadleaf coniferous mixed')
effects$level <- str_replace_all(effects$level, 'MAT', 'Mean annual temperature')
effects$group<-str_replace_all(effects$modAPA, 'modAPAsap', 'Saprophages')
effects$group<-str_replace_all(effects$group, 'modAPApre', 'Predators')
effects$group<-str_replace_all(effects$group, 'modAPAcarabfly', 'Flight-capable Carabidae')
effects$group<-str_replace_all(effects$group, 'modAPAcarabflightless', 'Flightless Carabidae')
effects$group<-str_replace_all(effects$group, 'modAPAcarab', 'Carabidae')
effects$group<-str_replace_all(effects$group, 'modAPAstaphy', 'Staphylinidae')
effects$group<-str_replace_all(effects$group, 'modAPAsilphid', 'Silphidae')
effects$group<-str_replace_all(effects$group, 'modAPAgeotrup', 'Geotrupidae')

effects$group<-str_replace(effects$group, "[:digit:]","")
effects$int<-"Fixed\neffects"
effects$int[which(str_detect(effects$level,":"))]<-"Interactive\neffects"
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$level<-fct_rev(factor(effects$level,levels=c("APA","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "APA:Mean annual temperature","APA:Evergreen coniferous","APA:Deciduous broadleaf","APA:Broadleaf coniferous mixed","APA:Urban","APA:Farmland",
                                                     "APA:Deer impacts")))
effects$group<-factor(factor(effects$group,levels=c("Silphidae","Geotrupidae","Staphylinidae","Flightless Carabidae","Flight-capable Carabidae","Carabidae","Saprophages","Predators")))
effects_sub<-subset(effects,level!="(Intercept)")
effects_sub$p_value<-ifelse(effects_sub$p_value<0.00001,0.00001,effects_sub$p_value)
subd<-levels(factor(effects_sub$int))
for( i in c(1,2)) {
    assign(paste0("plot", i),ggplot(data=subset(effects_sub, int==subd[i]),  aes(x=Estimate,y=group)) +
           geom_vline(xintercept=0,linetype=2,colour="black")+
           geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p_value),position=position_dodge(0.8),height=0)+
           geom_point(aes(group=response,shape=response),fill="white", col="white",position=position_dodge(0.8),size=2)+
           geom_point(aes(fill=response,group=response,alpha=p_value,shape=response),col="transparent",position=position_dodge(0.8),size=2)+
                   geom_vline(xintercept=0,linetype=2,colour="black")+
           xlab("Estimates")+
           ylab("")+
           theme(panel.grid.major = element_blank(),
                 panel.grid.minor = element_blank(),
                 panel.background = element_blank(),
                 panel.border=element_blank(),
                 axis.line=element_line(),
                 strip.background =element_blank(),
                 panel.spacing = unit(0.5,"lines"),
                 strip.text = element_text(size=7),
                 text=element_text(size=12,colour="black"),
                 legend.position="bottom",
                 legend.key = element_blank(),
                 legend.text=element_text(size=6),
                 axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
                 axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
                               legend.justification = "top")+
      scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
           scale_fill_viridis_d()+
           scale_colour_viridis_d()+
           scale_shape_manual(values=c(21,23,24,25))+
           facet_grid(int~level,scales="free",labeller=labeller(level = label_wrap_gen(20)))+
           labs(colour="Metric",fill="Metric",size="P value",alpha="P value",shape="Metric"))
  }

effects_plot_groups_apa<-ggarrange(plot1,plot2,labels = c("A.","B."), ncol=1,common.legend = TRUE,legend="bottom")
png(filename = "effects_mod_APA_groups.png", width = 6000, height =5000, units = "px",res = 600)
effects_plot_groups_apa
dev.off()


#############################
###############marginal for groups and ata and apa
#ATA

modlist=expand.grid("model"=c("modATApre","modATAsap","modATAcarab","modATAcarabfly","modATAcarabflightless","modATAstaphy","modATAsilphid","modATAgeotrup"),"num"=seq(1,4,1))
modlist$name<-paste0(modlist$model,modlist$num)
modlist$metric<-str_replace_all(modlist$num, '1', "Chao's S")
modlist$metric<-str_replace_all(modlist$metric, '2', "Richness")
modlist$metric<-str_replace_all(modlist$metric, '3', "Abundance")
modlist$metric<-str_replace_all(modlist$metric, '4', "Biomass")

effects_forestgroupmod<-data.frame()

for(i in c(1:length(modlist$model))) {
    ct<-test(emtrends(get(paste(modlist$name[i])), pairwise ~ ForestType, var = "ATA_scaled"))
  ef<-data.frame(ct$emtrends)
  ef$response<-modlist$metric[i]
  ef$name<-modlist$name[i]
  ef$level<-row.names(ef)
  effects_forestgroupmod<-smartbind(effects_forestgroupmod,ef)
  }

effects<-effects_forestgroupmod
effects$ForestType <- str_replace_all(effects$ForestType, 'EC', 'Evergreen\nconiferous')
effects$ForestType <- str_replace_all(effects$ForestType, 'DB', 'Deciduous\nbroadleaf')
effects$ForestType <- str_replace_all(effects$ForestType, 'BC', 'Broadleaf\nconiferous\nmixed')
effects$ForestType <- str_replace_all(effects$ForestType, 'EB', 'Evergreen\nbroadleaf')
effects$ForestType<-factor(effects$ForestType,levels=c("Evergreen\nbroadleaf",
                                                       "Broadleaf\nconiferous\nmixed",
                                                       "Evergreen\nconiferous",
                                                       "Deciduous\nbroadleaf"))
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$group<-str_replace_all(effects$name, 'modATAsap', 'Saprophages')
effects$group<-str_replace_all(effects$group, 'modATApre', 'Predators')
effects$group<-str_replace_all(effects$group, 'modATAcarabfly', 'Flight-capable Carabidae')
effects$group<-str_replace_all(effects$group, 'modATAcarabflightless', 'Flightless Carabidae')
effects$group<-str_replace_all(effects$group, 'modATAcarab', 'Carabidae')
effects$group<-str_replace_all(effects$group, 'modATAstaphy', 'Staphylinidae')
effects$group<-str_replace_all(effects$group, 'modATAsilphid', 'Silphidae')
effects$group<-str_replace_all(effects$group, 'modATAgeotrup', 'Geotrupidae')
effects$group<-str_replace(effects$group, "[:digit:]","")
effects$lower<-effects$ATA_scaled.trend-(1.96*effects$SE)
effects$upper<-effects$ATA_scaled.trend+(1.96*effects$SE)
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))

effects$group<-factor(effects$group,levels=c("Silphidae","Geotrupidae","Staphylinidae","Flightless Carabidae","Flight-capable Carabidae","Carabidae","Saprophages","Predators"))
effects$level<-fct_rev(factor(effects$level,levels=c("ATA","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "ATA:Mean annual temperature","ATA:Evergreen coniferous","ATA:Deciduous broadleaf","ATA:Broadleaf coniferous mixed","ATA:Urban","ATA:Farmland",
                                                     "ATA:Deer impacts")))
effects$ForestType <-(factor(effects$ForestType,levels=c("Evergreen\nbroadleaf","Broadleaf\nconiferous\nmixed","Evergreen\nconiferous","Deciduous\nbroadleaf")))

p<-ggplot(data=effects,  aes(x=ATA_scaled.trend,y=group,group=response)) +
  geom_vline(xintercept=0,linetype=2,colour="black")+
  geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p.value),height=0,position=position_dodge(0.95))+
  geom_col(aes(fill=response,alpha=p.value),position=position_dodge(0.95))+
  geom_hline(yintercept=c(1.5,2.5,3.5,6.5,7.5),linetype=3,colour="grey")+
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        panel.spacing = unit(0.5,"lines"),
          text=element_text(size=12,colour="black"),
        legend.position="bottom",
        legend.spacing = unit(1,"cm"),
        legend.key = element_blank(),
        legend.text=element_text(size=8),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
          legend.justification = "top")+
  scale_fill_viridis_d(option="D")+
  scale_colour_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0.2),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  facet_grid(.~ForestType,space="free",scales="free",labeller=labeller(level = label_wrap_gen(8)))+
  scale_x_continuous(breaks=c(seq(-1.5,1.5, 0.5)))+
  labs(colour="",fill="",alpha="P value")+
  guides(size="none",
         fill=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         colour=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         alpha=guide_legend(title.position = "top",title.hjust = 0.5,reverse=T))

png(filename = "forests_plot_groups_ATA.png", width = 4500, height =2700, units = "px",res = 600)
p
dev.off()

#APA

modlist=expand.grid("model"=c("modAPApre","modAPAsap","modAPAcarab","modAPAcarabfly","modAPAcarabflightless","modAPAstaphy","modAPAsilphid","modAPAgeotrup"),"num"=seq(1,4,1))
modlist$name<-paste0(modlist$model,modlist$num)
modlist$metric<-str_replace_all(modlist$num, '1', "Chao's S")
modlist$metric<-str_replace_all(modlist$metric, '2', "Richness")
modlist$metric<-str_replace_all(modlist$metric, '3', "Abundance")
modlist$metric<-str_replace_all(modlist$metric, '4', "Biomass")

effects_forestgroupmod<-data.frame()
for(i in c(1:length(modlist$model))) {
    ct<-test(emtrends(get(paste(modlist$name[i])), pairwise ~ ForestType, var = "APA_scaled"))
  ef<-data.frame(ct$emtrends)
  ef$response<-modlist$metric[i]
  ef$name<-modlist$name[i]
  ef$level<-row.names(ef)
  effects_forestgroupmod<-smartbind(effects_forestgroupmod,ef)
  }

effects<-effects_forestgroupmod
effects$ForestType <- str_replace_all(effects$ForestType, 'EC', 'Evergreen\nconiferous')
effects$ForestType <- str_replace_all(effects$ForestType, 'DB', 'Deciduous\nbroadleaf')
effects$ForestType <- str_replace_all(effects$ForestType, 'BC', 'Broadleaf\nconiferous\nmixed')
effects$ForestType <- str_replace_all(effects$ForestType, 'EB', 'Evergreen\nbroadleaf')
effects$ForestType<-factor(effects$ForestType,levels=c("Evergreen\nbroadleaf",
                                                       "Broadleaf\nconiferous\nmixed",
                                                       "Evergreen\nconiferous",
                                                       "Deciduous\nbroadleaf"))
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$group<-str_replace_all(effects$name, 'modAPAsap', 'Saprophages')
effects$group<-str_replace_all(effects$group, 'modAPApre', 'Predators')
effects$group<-str_replace_all(effects$group, 'modAPAcarabfly', 'Flight-capable Carabidae')
effects$group<-str_replace_all(effects$group, 'modAPAcarabflightless', 'Flightless Carabidae')
effects$group<-str_replace_all(effects$group, 'modAPAcarab', 'Carabidae')
effects$group<-str_replace_all(effects$group, 'modAPAstaphy', 'Staphylinidae')
effects$group<-str_replace_all(effects$group, 'modAPAsilphid', 'Silphidae')
effects$group<-str_replace_all(effects$group, 'modAPAgeotrup', 'Geotrupidae')
effects$group<-str_replace(effects$group, "[:digit:]","")
effects$lower<-effects$APA_scaled.trend-(1.96*effects$SE)
effects$upper<-effects$APA_scaled.trend+(1.96*effects$SE)
effects$response<-fct_rev(factor(effects$response,levels=c("Richness","Chao's S","Abundance","Biomass")))
effects$group<-factor(effects$group,levels=c("Silphidae","Geotrupidae","Staphylinidae","Flightless Carabidae","Flight-capable Carabidae","Carabidae","Saprophages","Predators"))
effects$level<-fct_rev(factor(effects$level,levels=c("APA","Mean annual temperature","Evergreen coniferous","Deciduous broadleaf","Broadleaf coniferous mixed","Urban","Farmland","Deer impacts","(Intercept)",
                                                     "APA:Mean annual temperature","APA:Evergreen coniferous","APA:Deciduous broadleaf","APA:Broadleaf coniferous mixed","APA:Urban","APA:Farmland",
                                                     "APA:Deer impacts")))
effects$ForestType <-(factor(effects$ForestType,levels=c("Evergreen\nbroadleaf","Broadleaf\nconiferous\nmixed","Evergreen\nconiferous","Deciduous\nbroadleaf")))

p<-ggplot(data=effects,  aes(x=APA_scaled.trend,y=group,group=response)) +
  geom_vline(xintercept=0,linetype=2,colour="black")+
  geom_errorbarh(aes(xmin=lower,xmax=upper,colour=response,alpha=p.value),height=0,position=position_dodge(0.95))+
 geom_col(aes(fill=response,alpha=p.value),position=position_dodge(0.95))+
  geom_hline(yintercept=c(1.5,2.5,3.5,6.5,7.5),linetype=3,colour="grey")+
  
  xlab("Estimated marginal means")+
  ylab("")+
  theme(panel.grid.major = element_blank(),
        panel.grid.minor = element_blank(),
        panel.background = element_blank(),
        panel.border=element_blank(),
        axis.line=element_line(),
        strip.background =element_blank(),
        panel.spacing = unit(0.5,"lines"),
            text=element_text(size=12,colour="black"),
        legend.position="bottom",
        legend.spacing = unit(1,"cm"),
               legend.key = element_blank(),
        legend.text=element_text(size=8),
        axis.text.y=element_text(angle=0, vjust=0.5,colour="black",size=8),
        axis.text.x=element_text(angle=0, vjust=1,hjust=0.5,colour="black",size=8),
     legend.justification = "top")+
  scale_fill_viridis_d(option="D")+
  scale_colour_viridis_d()+
  scale_alpha_continuous(limits = c(0.00001,0.99999999999), range=c(1,0),trans="sqrt",breaks=c(0.00001,0001,0.001,0.01,0.05,0.1,1),labels=c("0.00001","0.0001","0.001","0.01","0.05","0.1","1"))+
  facet_grid(.~ForestType,space="free",scales="free",labeller=labeller(level = label_wrap_gen(8)))+
  scale_x_continuous(breaks=c(seq(-1.5,1.5, 0.5)))+
  labs(colour="",fill="",alpha="P value")+
  guides(size="none",
         fill=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         colour=guide_legend(title.hjust = 0.5,reverse=T,ncol=2),
         alpha=guide_legend(title.position = "top",title.hjust = 0.5,reverse=T))

png(filename = "forests_plot_groups_APA.png", width = 4500, height =2700, units = "px",res = 600)
p
dev.off()

#save all models fitted in environment
models <- Filter( function(x) 'glmmTMB' %in% class( get(x) ), ls() )
save(list = models, file="allmodels.RData")

load("allmodels.RData")


########################Model tables#####################

df<-data.frame("group"=c("mod","modpre","modsap","modcarfly", "modcarflightless","modcarab","modstaphy","modsilphid","modgeotrup"))
dfATA<-data.frame("group"=c("mod_ata","modATApre","modATAsap","modATAcarabfly", "modATAcarabflightless","modATAcarab","modATAstaphy","modATAsilphid","modATAgeotrup"))
dfAPA<-data.frame("group"=c("mod_apa","modAPApre","modAPAsap","modAPAcarabfly", "modAPAcarabflightless","modAPAcarab","modAPAstaphy","modAPAsilphid","modAPAgeotrup"))
df<-rbind(df,dfATA,dfAPA)
df<-expand.grid(seq(1,4,1),group=df$group)
df$mod<-paste0(df$group,df$Var1)

mod_table<-data.frame()
for (i in 1:length(df$mod)) {
  
  load(file=paste0(df$mod[i],".RData"))
  tempmod<-get(paste0(df$mod[i]))
  temp<-data.frame(summary(tempmod)$coef$cond)
  colnames(temp)[length(colnames(temp))]<-"P value"
  temp$Distribution<-as.character(tempmod$modelInfo$family$family)
  temp$AIC<-AIC(tempmod)
  temp$Predictor<-row.names(temp)
  temp$model<-df$mod[i]
  mod_table<-smartbind(mod_table,temp)
  }

mod_table$Metric<-"not categorised"
mod_table$Metric[str_detect(mod_table$model,'1')]<-"Chao's S"
mod_table$Metric[str_detect(mod_table$model,'2')]<-"Richness"
mod_table$Metric[str_detect(mod_table$model,'3')]<-"Abundance"
mod_table$Metric[str_detect(mod_table$model,'4')]<-"Biomass"

mod_table$Grouping<-gsub('[0-9]+', '', mod_table$model)
mod_table$Grouping[str_which(mod_table$Grouping,'\\bmod\\b')]<-'All'
mod_table$Grouping[str_which(mod_table$Grouping,'mod_a')]<-'All'
mod_table$Grouping[str_which(mod_table$Grouping,'\\bmodAPAcarab\\b')]<-'Carabidae'
mod_table$Grouping[str_which(mod_table$Grouping,'\\bmodATAcarab\\b')]<-'Carabidae'
mod_table$Grouping[str_which(mod_table$Grouping,'\\bmodcarab\\b')]<-'Carabidae'
mod_table$Grouping[str_which(mod_table$Grouping,'pre')]<-'Predators'
mod_table$Grouping[str_detect(mod_table$Grouping,'sap')]<-'Saprophages'
mod_table$Grouping[str_detect(mod_table$Grouping,'carfly')]<-'Flight-capable Carabidae'
mod_table$Grouping[str_detect(mod_table$Grouping,'carflightless')]<-'Flightless Carabidae'
mod_table$Grouping[str_detect(mod_table$Grouping,'carabfly')]<-'Flight-capable Carabidae'
mod_table$Grouping[str_detect(mod_table$Grouping,'carabflightless')]<-'Flightless Carabidae'
mod_table$Grouping[str_detect(mod_table$Grouping,'staphy')]<-"Staphylinidae"
mod_table$Grouping[str_detect(mod_table$Grouping,'silphid')]<-'Silphidae'
mod_table$Grouping[str_detect(mod_table$Grouping,'geotrup')]<-'Geotrupidae'

mod_table$Test<-"Time"
mod_table$Test[str_detect(mod_table$model,'ATA')]<-'Annual temperature anomoly'
mod_table$Test[str_detect(mod_table$model,'APA')]<-'Annual precipitation anomoly'
mod_table$Test[str_detect(mod_table$model,'_ata')]<-'Annual temperature anomoly'
mod_table$Test[str_detect(mod_table$model,'_apa')]<-'Annual precipitation anomoly'

mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'yyyy_scaled', 'Time')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'ForestType', '')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'urban_factorurban', 'Urban')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'farmland.mean_1k_scaled', 'Farmland')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'MATave_scaled', "MAT")
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'Deer_presence1', 'Deer presence')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'Deer_veg_impact1', 'Deer impacts')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'MAT:Time', 'Time:MAT')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'BC:Time', 'Time:BC')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'EC:Time', 'Time:EC')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'DB:Time', 'Time:DB')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'Deer impacts:Time', 'Time:Deer impacts')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'Deer presence:Time', 'Time:Deer presence')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'Urban:Time', 'Time:Urban')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'EC', 'Evergreen coniferous')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'DB', 'Deciduous broadleaf')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'BC', 'Broadleaf coniferous mixed')
mod_table$Predictor <- str_replace_all(mod_table$Predictor, 'MAT', 'Mean annual temperature')
mod_table$Predictor

mod_table$Distribution <-str_replace_all(mod_table$Distribution, 'nbinom2', 'Negative binomial')
mod_table$Distribution <-str_replace_all(mod_table$Distribution, 'poisson', 'Poisson')
mod_table$Distribution <-str_replace_all(mod_table$Distribution, 'gaussian', 'Gaussian')

mod_table$z.value<-NULL
mod_table$SE<-mod_table$Std..Error
mod_table$Std..Error<-NULL

mod_table$Estimate<-round(mod_table$Estimate,3)
mod_table$SE<-round(mod_table$SE,3)
mod_table$`P value`<-scales::pvalue(mod_table$`P value`)
mod_table<-mod_table[,c("Test","Grouping","Metric","Predictor", "Estimate","P value","Distribution","AIC")]
mod_table$Grouping<-factor(mod_table$Grouping, levels=c("All","Predators","Saprophages",
                                                        "Carabidae", "Flight-capable Carabidae","Flightless Carabidae",
                                                        "Staphylinidae","Geotrupidae","Silphidae"))
set_flextable_defaults(
  font.size = 10, theme_fun = theme_vanilla,
  padding.left = 1,font.family = "Times New Roman",line_spacing = 1)

#Time models
time_mod_table<-subset(mod_table,Test=="Time")
time_mod_table$Test<-NULL

ft<-flextable(time_mod_table) %>% padding(padding = 0, part = "all") %>% align(align = "left", part = "all")
ft<-merge_v(ft, j = c("Grouping","AIC","Metric","Distribution"), target = NULL, part = "body", combine = TRUE)
ft<-autofit(ft)
ft<-valign(ft, valign = "top", part = "all")
ft_time<-ft

#ATA models
ATA_mod_table<-subset(mod_table,Test=="Annual temperature anomoly")
ATA_mod_table$Test<-NULL

ft<-flextable(ATA_mod_table) %>% padding(padding = 0, part = "all") %>% align(align = "left", part = "all")
ft<-merge_v(ft, j = c("Grouping","AIC","Metric","Distribution"), target = NULL, part = "body", combine = TRUE)
ft<-autofit(ft)
ft<-valign(ft, valign = "top", part = "all")
ft_ATA<-ft

#APA models
APA_mod_table<-subset(mod_table,Test=="Annual precipitation anomoly")
APA_mod_table$Test<-NULL

ft<-flextable(APA_mod_table) %>% padding(padding = 0, part = "all") %>% align(align = "left", part = "all")
ft<-merge_v(ft, j = c("Grouping","AIC","Metric","Distribution"), target = NULL, part = "body", combine = TRUE)
ft<-autofit(ft)
ft<-valign(ft, valign = "top", part = "all")
ft_APA<-ft

save_as_docx( "Table S7. Model statistics for full models testing the effects of forest type, urban cover, farmland cover, the impacts of deer and their interactions with time. " = ft_time, 
              "Table S8. Model statistics for full models testing the effects of forest type, urban cover, farmland cover, the impacts of deer and their interactions with annual temperature anomaly (ATA)." = ft_ATA,
              "Table S9. Model statistics for full models testing the effects of forest type, urban cover, farmland cover, the impacts of deer and their interactions with annual precipitation anomaly (APA)." = ft_APA, 
              path = "Tables.docx")



